@@ -21,4 +21,4 @@ if [ ! -d "./build" ]; then
     echo "Please run: 'python setup.py build' before $0"
 fi
 
-./software-center $@
+./bin/software-center $@
