@@ -15,9 +15,3 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-from installbackend import get_install_backend
-
-# mvo: this is only there to make pyflakes silent (otherwise it thinks
-#      its a unused import)
-get_install_backend
