@@ -41,7 +41,7 @@ class LoginBackendDbusSSO(LoginBackend):
 
     def __init__(self, window_id, appname, help_text):
         super(LoginBackendDbusSSO, self).__init__()
-        self.appname = appname
+        self.appname = 'Ubuntu One'
         self.help_text = help_text
         self.bus = dbus.SessionBus()
         obj = self.bus.get_object(bus_name=DBUS_BUS_NAME,
@@ -61,8 +61,7 @@ class LoginBackendDbusSSO(LoginBackend):
         self._credentials = None
 
     def _get_params(self):
-        p = {'ui_executable': 'software-center-sso-gtk',
-             }
+        p = {}
         if self.help_text:
             p['help_text'] = utf8(self.help_text)
         if self._window_id:
