@@ -25,7 +25,7 @@ from softwarecenter.backend.ubuntusso import get_ubuntu_sso_backend
 from softwarecenter.enums import SOFTWARE_CENTER_NAME_KEYRING
 
 import datetime
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 import logging
 
 from gettext import gettext as _
@@ -39,12 +39,12 @@ class OneConfHandler(GObject.GObject):
         "show-oneconf-changed": (GObject.SIGNAL_RUN_LAST,
                                  GObject.TYPE_NONE,
                                  (GObject.TYPE_PYOBJECT,),
-                                ),
+                                 ),
         "last-time-sync-changed": (GObject.SIGNAL_RUN_LAST,
                                    GObject.TYPE_NONE,
                                    (GObject.TYPE_PYOBJECT,),
-                                  ),
-        }
+                                   ),
+    }
 
     def __init__(self, oneconfviewpickler):
         '''Controller of the installed pane'''
@@ -67,9 +67,9 @@ class OneConfHandler(GObject.GObject):
 
         # refresh host list
         self._refreshing_hosts = False
-        GObject.timeout_add_seconds(MIN_TIME_WITHOUT_ACTIVITY,
+        GLib.timeout_add_seconds(MIN_TIME_WITHOUT_ACTIVITY,
             self.get_latest_oneconf_sync)
-        GObject.idle_add(self.refresh_hosts)
+        GLib.idle_add(self.refresh_hosts)
 
     def refresh_hosts(self):
         """refresh hosts list in the panel view"""
