@@ -7,7 +7,7 @@ from piston_mini_client import (
     returns,
     returns_json,
     returns_list_of,
-    )
+)
 from piston_mini_client.validators import validate_pattern, validate
 from piston_mini_client.failhandlers import APIError
 
@@ -64,7 +64,7 @@ class RatingsAndReviewsAPI(PistonAPI):
     @returns_list_of(ReviewsStats)
     @network_delay
     def review_stats(self, origin='any', distroseries='any', days=None,
-        valid_days=(1, 3, 7)):
+                     valid_days=(1, 3, 7)):
         if self._fake_settings.get_setting('review_stats_error'):
             raise APIError(self._exception_msg)
 
@@ -81,7 +81,7 @@ class RatingsAndReviewsAPI(PistonAPI):
                  'ratings_total': str(random.randrange(1, 200)),
                  'ratings_average': str(random.randrange(0, 5)),
                  'histogram': None
-            }
+                 }
             stats.append(s)
 
         return json.dumps(stats)
@@ -97,7 +97,8 @@ class RatingsAndReviewsAPI(PistonAPI):
     @returns_list_of(ReviewDetails)
     @network_delay
     def get_reviews(self, packagename, language='any', origin='any',
-        distroseries='any', version='any', appname='', page=1, sort='helpful'):
+                    distroseries='any', version='any', appname='',
+                    page=1, sort='helpful'):
 
         # work out how many reviews to return for pagination
         if page <= self._fake_settings.get_setting('review_pages'):
@@ -151,7 +152,7 @@ class RatingsAndReviewsAPI(PistonAPI):
                 "reviewer_displayname": "Fake User",
                 "package_name": review.package_name,
                 "distroseries": review.distroseries
-            }
+        }
         return json.dumps(r)
 
     @validate('review_id', int)
@@ -224,7 +225,7 @@ class RatingsAndReviewsAPI(PistonAPI):
                 'username': response_user,
                 'useful': random.choice(['True', 'False']),
                 'review_id': review_id
-                }
+            }
             return json.dumps([response])
 
         #set up review ids to honour requested and also add randoms
@@ -232,7 +233,7 @@ class RatingsAndReviewsAPI(PistonAPI):
         id_list = self._fake_settings.get_setting('required_review_ids')
         id_quantity = len(id_list)
 
-        #figure out if we need to accomodate requested review ids
+        #figure out if we need to accommodate requested review ids
         if id_quantity == 0:
             rand_id_start = 0
         else:
@@ -248,10 +249,10 @@ class RatingsAndReviewsAPI(PistonAPI):
                 id = random.randint(rand_id_start, 10000)
 
             u = {
-                 'username': username,
-                 'useful': random.choice(['True', 'False']),
-                 'review_id': id
-                }
+                'username': username,
+                'useful': random.choice(['True', 'False']),
+                'review_id': id
+            }
             votes.append(u)
 
         return json.dumps(votes)
