@@ -36,20 +36,20 @@ class SoftwareCenterAgent(GObject.GObject):
         "available-for-me": (GObject.SIGNAL_RUN_LAST,
                              GObject.TYPE_NONE,
                              (GObject.TYPE_PYOBJECT,),
-                            ),
+                             ),
         "available": (GObject.SIGNAL_RUN_LAST,
                       GObject.TYPE_NONE,
                       (GObject.TYPE_PYOBJECT,),
-                     ),
+                      ),
         "exhibits": (GObject.SIGNAL_RUN_LAST,
                      GObject.TYPE_NONE,
                      (GObject.TYPE_PYOBJECT,),
-                    ),
+                     ),
         "error": (GObject.SIGNAL_RUN_LAST,
                   GObject.TYPE_NONE,
                   (str,),
-                 ),
-        }
+                  ),
+    }
 
     def __init__(self, ignore_cache=False, xid=None):
         GObject.GObject.__init__(self)
@@ -106,7 +106,7 @@ class SoftwareCenterAgent(GObject.GObject):
             complete_only=True)
 
     def _on_query_available_for_me_data(self, spawner,
-        piston_available_for_me):
+                                        piston_available_for_me):
         self.emit("available-for-me", piston_available_for_me)
 
     def query_exhibits(self):
@@ -144,7 +144,7 @@ if __name__ == "__main__":
         print ("_available: %s" % available)
 
     def _available_for_me(agent, available_for_me):
-        print ("_availalbe_for_me: %s" % available_for_me)
+        print ("_available_for_me: %s" % available_for_me)
 
     def _exhibits(agent, exhibits):
         print ("exhibits: " % exhibits)
