@@ -30,12 +30,11 @@ from paths import SOFTWARE_CENTER_CONFIG_FILE
 LOG = logging.getLogger(__name__)
 
 
-class SoftwareCenterConfig(object, SafeConfigParser):
+class SoftwareCenterConfig(SafeConfigParser):
 
     SECTIONS = ("general", "reviews")
 
     def __init__(self, config):
-        object.__init__(self)
         SafeConfigParser.__init__(self)
         # imported here to avoid cycle
         from utils import safe_makedirs
