@@ -637,7 +637,7 @@ class StoreDatabase(GObject.GObject):
             yield doc
 
 
-class FakeMSetItem():
+class FakeMSetItem(object):
     def __init__(self, doc):
         self.document = doc
 
