@@ -22,7 +22,7 @@ import time
 import threading
 import xapian
 
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 
 from softwarecenter.enums import (SortMethods,
                                   XapianValues,
@@ -39,12 +39,12 @@ LOG = logging.getLogger(__name__)
 class AppEnquire(GObject.GObject):
     """
     A interface to enquire data from a xapian database.
-    It can combined with any xapian querry and with
+    It can combined with any xapian query and with
     a generic filter function (that can filter on data not
     available in xapian)
     """
 
-    # signal emited
+    # signal emitted
     __gsignals__ = {"query-complete": (GObject.SIGNAL_RUN_FIRST,
                                        GObject.TYPE_NONE,
                                        ()),
@@ -56,7 +56,7 @@ class AppEnquire(GObject.GObject):
 
         :Parameters:
         - `cache`: apt cache (for stuff like the overlay icon)
-        - `db`: a xapian.Database that contians the applications
+        - `db`: a xapian.Database that contains the applications
         """
         GObject.GObject.__init__(self)
         self.cache = cache
@@ -96,7 +96,7 @@ class AppEnquire(GObject.GObject):
             target=self._blocking_perform_search, name=thread_name)
         t.start()
         # don't block the UI while the thread is running
-        context = GObject.main_context_default()
+        context = GLib.main_context_default()
         while not self._perform_search_complete:
             time.sleep(0.02)  # 50 fps
             while context.pending():
@@ -125,14 +125,14 @@ class AppEnquire(GObject.GObject):
         return (nr_apps, nr_pkgs)
 
     def _blocking_perform_search(self):
-        # WARNING this call may run in a thread, so its *not*
+        # WARNING this call may run in a thread, so it's *not*
         #         allowed to touch gtk, otherwise hell breaks loose
 
         # performance only: this is only needed to avoid the
         # python __call__ overhead for each item if we can avoid it
 
         # use a unique instance of both enquire and xapian database
-        # so concurrent queries dont result in an inconsistent database
+        # so concurrent queries don't result in an inconsistent database
 
         # an alternative would be to serialise queries
         enquire = xapian.Enquire(self.db.xapiandb)
@@ -193,7 +193,7 @@ class AppEnquire(GObject.GObject):
             if self.sortmode == SortMethods.BY_CATALOGED_TIME:
                 sorter = xapian.MultiValueKeyMaker()
                 if (self.db._axi_values and
-                    "catalogedtime" in self.db._axi_values):
+                        "catalogedtime" in self.db._axi_values):
                     sorter.add_value(
                         self.db._axi_values["catalogedtime"])
                 sorter.add_value(XapianValues.DB_CATALOGED_TIME)
@@ -320,7 +320,7 @@ class AppEnquire(GObject.GObject):
             self.match_docids = set()
 
         # we support single and list search_queries,
-        # if list we append them one by one
+        # if list, we append them one by one
         with ExecutionTime("populate model from query: '%s' (threaded: %s)" % (
                 " ; ".join([str(q) for q in self.search_query]),
                 self.nonblocking_load), with_traceback=False):
