@@ -23,10 +23,10 @@ import apt_pkg
 import logging
 import os
 
-from gi.repository import GObject
 from gi.repository import Gio
+from gi.repository import GLib
 
-# we need this to get the size calculation done asyncronously and reliable
+# we need this to get the size calculation done asynchronously and reliable
 from aptdaemon.client import AptClient
 
 from softwarecenter.db.pkginfo import PackageInfo, _Version
@@ -39,7 +39,7 @@ LOG = logging.getLogger(__name__)
 class GtkMainIterationProgress(apt.progress.base.OpProgress):
     """Progress that just runs the main loop"""
     def update(self, percent=0):
-        context = GObject.main_context_default()
+        context = GLib.main_context_default()
         while context.pending():
             context.iteration()
 
@@ -94,6 +94,10 @@ class AptCacheVersion(_Version):
     def origins(self):
         return self.ver.origins
 
+    @property
+    def record(self):
+        return self.ver.record
+
     @property
     def downloadable(self):
         return self.ver.downloadable
@@ -174,47 +178,47 @@ class AptCache(PackageInfo):
 
     def is_available(self, pkgname):
         return (pkgname in self._cache and
-                self._cache[pkgname].candidate)
+                    self._cache[pkgname].candidate)
 
     def get_installed(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].is_installed):
+                not self._cache[pkgname].is_installed):
             return None
         return AptCacheVersion(self._cache[pkgname].installed)
 
     def get_candidate(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return None
         return AptCacheVersion(self._cache[pkgname].candidate)
 
     def get_versions(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return []
         return [AptCacheVersion(v) for v in self._cache[pkgname].versions]
 
     def get_section(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return ''
         return self._cache[pkgname].candidate.section
 
     def get_summary(self, pkgname):
         if (pkgname not in self._cache or
-        not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return ''
         return self._cache[pkgname].candidate.summary
 
     def get_description(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return ''
         return self._cache[pkgname].candidate.description
 
     def get_website(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return ''
         return self._cache[pkgname].candidate.homepage
 
@@ -225,13 +229,13 @@ class AptCache(PackageInfo):
 
     def get_size(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return 0
         return self._cache[pkgname].candidate.size
 
     def get_installed_size(self, pkgname):
         if (pkgname not in self._cache or
-            not self._cache[pkgname].candidate):
+                not self._cache[pkgname].candidate):
             return 0
         return self._cache[pkgname].candidate.installed_size
 
@@ -264,7 +268,7 @@ class AptCache(PackageInfo):
 
     # implementation specific code
 
-    # temporarely return a full apt.Package so that the tests and the
+    # temporarily return a full apt.Package so that the tests and the
     # code keeps working for now, this needs to go away eventually
     # and get replaced with the abstract _Package class
     #def __getitem__(self, key):
@@ -277,13 +281,13 @@ class AptCache(PackageInfo):
         return self._cache.__contains__(k)
 
     def _on_apt_finished_stamp_changed(self, monitor, afile, other_file,
-        event):
+                                       event):
         if not event == Gio.FileMonitorEvent.CHANGES_DONE_HINT:
             return
         if self._timeout_id:
-            GObject.source_remove(self._timeout_id)
+            GLib.source_remove(self._timeout_id)
             self._timeout_id = None
-        self._timeout_id = GObject.timeout_add_seconds(10, self.open)
+        self._timeout_id = GLib.timeout_add_seconds(10, self.open)
 
     def _get_rdepends_by_type(self, pkg, type, onlyInstalled):
         rdeps = set()
@@ -297,8 +301,10 @@ class AptCache(PackageInfo):
             dep_type = rdep.dep_type_untranslated
             if dep_type in type:
                 rdep_name = rdep.parent_pkg.name
-                if rdep_name in self._cache and (not onlyInstalled or
-                (onlyInstalled and self._cache[rdep_name].is_installed)):
+                if (rdep_name in self._cache and
+                        (not onlyInstalled or (
+                            onlyInstalled and
+                            self._cache[rdep_name].is_installed))):
                     rdeps.add(rdep.parent_pkg.name)
         return rdeps
 
@@ -341,7 +347,7 @@ class AptCache(PackageInfo):
                 continue
             else:
                 if (pkg.is_installed and
-                    pkg.is_auto_removable):
+                        pkg.is_auto_removable):
                     installed_auto_deps.add(dep_name)
         return installed_auto_deps
 
@@ -354,7 +360,7 @@ class AptCache(PackageInfo):
             if not pkg.candidate:
                 continue
             for item in pkg.candidate.origins:
-                context = GObject.main_context_default()
+                context = GLib.main_context_default()
                 while context.pending():
                     context.iteration()
                 if item.origin:
@@ -375,7 +381,7 @@ class AptCache(PackageInfo):
 
     def get_origin(self, pkgname):
         """
-        return a uniqe origin for the given package name. currently
+        return a unique origin for the given package name. currently
         this will use
         """
         if not pkgname in self._cache or not self._cache[pkgname].candidate:
@@ -396,9 +402,9 @@ class AptCache(PackageInfo):
         # FIXME: test for more properties here?
         for it in self._cache._cache.file_list:
             if (it.component != "" and
-                it.component == component and
-                it.archive != "" and
-                it.archive == distro_codename):
+                    it.component == component and
+                    it.archive != "" and
+                    it.archive == distro_codename):
                 return True
         return False
 
@@ -572,7 +578,7 @@ class AptCache(PackageInfo):
         # Check if the package is provided in the release
         for version in pkg.versions:
             if [origin for origin in version.origins
-                if origin.archive == archive_suite]:
+                    if origin.archive == archive_suite]:
                 break
         else:
             return False
@@ -580,7 +586,7 @@ class AptCache(PackageInfo):
             pkg._pkg, version._cand, archive_suite)
         return res
 
-    # space calulcation stuff
+    # space calculation stuff
     def _on_total_size_calculation_done(self, trans, space):
         pkgname = trans.packages[0][0]
         self.emit(
@@ -653,11 +659,11 @@ class AptCache(PackageInfo):
 
         def _addons_filter(addon):
             """ helper for get_addons that filters out unneeded ones """
-            # we don't know about this one (prefectly legal for suggests)
+            # we don't know about this one (perfectly legal for suggests)
             if not addon in self._cache:
                 LOG.debug("not in cache %s" % addon)
                 return False
-            # can happen via "lonley" depends
+            # can happen via "lonely" depends
             if addon == pkg.name:
                 LOG.debug("circular %s" % addon)
                 return False
@@ -667,10 +673,9 @@ class AptCache(PackageInfo):
                 return False
             # get the pkg
             addon_pkg = self._cache[addon]
-            # we don't care for essential or important (or refrences
-            # to ourself)
-            if (addon_pkg.essential or
-                addon_pkg._pkg.important):
+            # we don't care for essential or important (or references
+            # to our self)
+            if addon_pkg.essential or addon_pkg._pkg.important:
                 LOG.debug("essential or important %s" % addon)
                 return False
             # we have it in our dependencies already
@@ -700,8 +705,7 @@ class AptCache(PackageInfo):
             return True
         #----------------------------------------------------------------
         # deb file, or pkg needing source, etc
-        if (not pkgname in self._cache or
-            not self._cache[pkgname].candidate):
+        if not pkgname in self._cache or not self._cache[pkgname].candidate:
             return ([], [])
 
         # initial setup
@@ -724,7 +728,7 @@ class AptCache(PackageInfo):
                 virtual_aptpkg_pkg)
             LOG.debug("renhances of %s: %s" % (provide, renhances))
             addons_sug += renhances
-            context = GObject.main_context_default()
+            context = GLib.main_context_default()
             while context.pending():
                 context.iteration()
 
@@ -744,19 +748,19 @@ class AptCache(PackageInfo):
                 if len(self._get_rdepends(pkgdep)) == 1:
                     # pkg is the only known package that depends on pkgdep
                     pkgdep_rec = self._get_recommends(pkgdep)
-                    LOG.debug("recommends from lonley dependency %s: %s" % (
+                    LOG.debug("recommends from lonely dependency %s: %s" % (
                             pkgdep, pkgdep_rec))
                     addons_rec += pkgdep_rec
                     pkgdep_sug = self._get_suggests(pkgdep)
-                    LOG.debug("suggests from lonley dependency %s: %s" % (
+                    LOG.debug("suggests from lonely dependency %s: %s" % (
                             pkgdep, pkgdep_sug))
                     addons_sug += pkgdep_sug
                     pkgdep_enh = self._get_renhances(pkgdep)
-                    LOG.debug("renhances from lonley dependency %s: %s" % (
+                    LOG.debug("renhances from lonely dependency %s: %s" % (
                             pkgdep, pkgdep_enh))
                     addons_sug += pkgdep_enh
 
-            context = GObject.main_context_default()
+            context = GLib.main_context_default()
             while context.pending():
                 context.iteration()
 
