@@ -427,9 +427,9 @@ class AppInfoParserBase(object):
                 if countrycode in blacklist:
                     if countrycode in whitelist:
                         LOG.debug("%r.make_doc: %r black AND whitelisted for "
-                                  "region %r. Treating as blacklisted.", 
+                                  "region %r. Treating as blacklisted.",
                                   self.__class__.__name__, name, countrycode)
-                        
+
                     LOG.debug("%r.make_doc: skipping region restricted app %r "
                              "(blacklisted)", self.__class__.__name__, name)
                     return
@@ -934,6 +934,23 @@ class DesktopConfigParser(RawConfigParser, DesktopTagSectionParser):
         return self._filename
 
 
+class ScopeConfigParser(DesktopConfigParser):
+    """Thin wrapper to handle Scope files."""
+
+    SCOPE = "Scope"
+
+    def _get_option_desktop(self, key):
+        # Mark scopes as Type=Scope.
+        if key.lower() == 'type':
+            return 'Scope'
+        value = super(ScopeConfigParser, self)._get_option_desktop(key)
+        if value is not None:
+            return value
+        # Fall back to values from the SCOPE section.
+        if self.has_option(self.SCOPE, key):
+            return self.get(self.SCOPE, key)
+
+
 def ascii_upper(key):
     """Translate an ASCII string to uppercase
     in a locale-independent manner."""
@@ -1019,13 +1036,16 @@ def update_from_app_install_data(db, cache, datadir=None):
     if not datadir:
         datadir = softwarecenter.paths.APP_INSTALL_DESKTOP_PATH
     context = GLib.main_context_default()
-    for desktopf in glob(datadir + "/*.desktop"):
+    for desktopf in glob(datadir + "/*.desktop") + glob(datadir + "/*.scope"):
         LOG.debug("processing %r", desktopf)
         # process events
         while context.pending():
             context.iteration()
         try:
-            parser = DesktopConfigParser()
+            if desktopf.endswith('.scope'):
+                parser = ScopeConfigParser()
+            else:
+                parser = DesktopConfigParser()
             parser.read(desktopf)
             parser.index_app_info(db, cache)
         except Exception as e:
