@@ -59,6 +59,12 @@ class Distro(object):
         """
         return _("Software Center")
 
+    def get_app_id(self):
+        """
+        The application-id (as used on the .desktop file)
+        """
+        return "software-center"
+
     def get_app_description(self):
         """
         The description of the application displayed in the about dialog
