@@ -1,7 +1,5 @@
-# Copyright (C) 2009 Canonical
 #
-# Authors:
-#  Michael Vogt
+# Copyright 2009-2013 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -37,6 +35,7 @@ class Ubuntu(Debian):
 
     # see __init__.py description
     DISTROSERIES = [
+        "saucy",
         "raring",
         "quantal",
         "precise",
@@ -81,6 +80,9 @@ class Ubuntu(Debian):
     def get_app_name(self):
         return _("Ubuntu Software Center")
 
+    def get_app_id(self):
+        return "ubuntu-software-center"
+
     def get_app_description(self):
         return _("Lets you choose from thousands of applications available "
                  "for Ubuntu.")
