@@ -668,8 +668,6 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         if (event.keyval == Gdk.keyval_from_name("x") and
                 event.state == Gdk.ModifierType.CONTROL_MASK):
             self.menuitem_edit.activate()
-            if self.menuitem_cut.get_sensitive():
-                self.menuitem_cut.activate()
 
         if (event.keyval == Gdk.keyval_from_name("c") and
                 event.state == Gdk.ModifierType.CONTROL_MASK):
@@ -938,7 +936,6 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         """
         edit_menu_items = [self.menuitem_undo,
                            self.menuitem_redo,
-                           self.menuitem_cut,
                            self.menuitem_copy,
                            self.menuitem_copy_web_link,
                            self.menuitem_paste,
@@ -964,10 +961,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
                     self.menuitem_undo.set_sensitive(True)
                 if len(self.active_pane.searchentry._redo_stack) > 0:
                     self.menuitem_redo.set_sensitive(True)
-                bounds = self.active_pane.searchentry.get_selection_bounds()
-                if bounds:
-                    self.menuitem_cut.set_sensitive(True)
-                    self.menuitem_copy.set_sensitive(True)
+
                 self.menuitem_paste.set_sensitive(True)
                 if self.active_pane.searchentry.get_text():
                     self.menuitem_delete.set_sensitive(True)
@@ -998,15 +992,10 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     def on_menuitem_redo_activate(self, menuitem):
         self.active_pane.searchentry.redo()
 
-    def on_menuitem_cut_activate(self, menuitem):
-        self.active_pane.searchentry.cut_clipboard()
-
     def on_menuitem_copy_activate(self, menuitem):
         if (self.active_pane and
                 self.active_pane.is_app_details_view_showing()):
             self.active_pane.app_details_view.desc.copy_clipboard()
-        elif self.active_pane:
-            self.active_pane.searchentry.copy_clipboard()
 
     def on_menuitem_paste_activate(self, menuitem):
         self.active_pane.searchentry.paste_clipboard()
@@ -1160,7 +1149,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     def on_menuitem_help_activate(self, menuitem):
         # run browser
         (pid, stdin, stdout, stderr) = GLib.spawn_async(
-            ["yelp", "ghelp:software-center"], flags=GObject.SPAWN_SEARCH_PATH)
+            ["yelp", "help:software-center"], flags=GObject.SPAWN_SEARCH_PATH)
 
     def on_menuitem_tos_activate(self, menuitem):
         webbrowser.open_new_tab(SOFTWARE_CENTER_TOS_LINK)
