@@ -18,6 +18,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 from gi.repository import GObject
+from gi.repository import GLib
 from gi.repository import Gtk, GdkPixbuf
 import logging
 import os
@@ -35,13 +36,16 @@ from softwarecenter.utils import (
     capitalize_first_word,
     utf8,
     unescape,
-    )
+)
 from softwarecenter.backend.installbackend import get_install_backend
 from softwarecenter.backend.reviews import get_review_loader
 from softwarecenter.paths import SOFTWARE_CENTER_ICON_CACHE_DIR
 
 from softwarecenter.db.categories import (
-    category_subcat, category_cat, CategoriesParser)
+    category_subcat,
+    category_cat,
+    CategoriesParser,
+)
 
 # global cache icons to speed up rendering
 _app_icon_cache = {}
@@ -58,7 +62,7 @@ class CategoryRowReference:
 
     def __init__(self, untranslated_name, display_name, subcats, pkg_count):
         self.untranslated_name = untranslated_name
-        self.display_name = GObject.markup_escape_text(utf8(display_name))
+        self.display_name = GLib.markup_escape_text(utf8(display_name))
         #self.subcategories = subcats
         self.pkg_count = pkg_count
         self.vis_count = pkg_count
@@ -94,7 +98,7 @@ class AppPropertiesHelper(GObject.GObject):
                          None,
                           (str, ),
                           ),
-        }
+    }
 
     def __init__(self, db, cache, icons, icon_size=48,
                  global_icon_cache=False):
@@ -211,8 +215,8 @@ class AppPropertiesHelper(GObject.GObject):
             summary = self.get_pkgname(doc)
 
         return "%s\n<small>%s</small>" % (
-                 GObject.markup_escape_text(appname),
-                 GObject.markup_escape_text(summary))
+            GLib.markup_escape_text(appname),
+            GLib.markup_escape_text(summary))
 
     def get_display_price(self, doc):
         app = self.db.get_application(doc)
@@ -272,7 +276,7 @@ class AppPropertiesHelper(GObject.GObject):
         if translated_catname == catname:
             # if no normal translation is found, try to find a escaped
             # translation (LP: #872760)
-            translated_catname = _(GObject.markup_escape_text(catname))
+            translated_catname = _(GLib.markup_escape_text(catname))
             # the parent expect the string unescaped
             translated_catname = unescape(translated_catname)
         return translated_catname
@@ -360,7 +364,7 @@ class AppGenericStore(AppPropertiesHelper):
     # the following methods ensure that the contents data is refreshed
     # whenever a transaction potentially changes it:
     def _on_transaction_started(self, backend, pkgname, appname, trans_id,
-        trans_type):
+                                trans_type):
         #~ self._refresh_transaction_map()
         pass
 
@@ -405,7 +409,7 @@ class AppGenericStore(AppPropertiesHelper):
             return False    # remove from sources on completion
 
         if self.current_matches is not None:
-            GObject.idle_add(buffer_icons)
+            GLib.idle_add(buffer_icons)
 
     def load_range(self, indices, step):
         # stub
@@ -421,13 +425,13 @@ class AppListStore(Gtk.ListStore, AppGenericStore):
         "appcount-changed": (GObject.SignalFlags.RUN_LAST,
                              None,
                              (GObject.TYPE_PYOBJECT, ),
-                            ),
+                             ),
         # meh, this is a signal from AppPropertiesHelper
         "needs-refresh": (GObject.SignalFlags.RUN_LAST,
                              None,
                              (str, ),
-                            ),
-        }
+                          ),
+    }
 
     def __init__(self, db, cache, icons, icon_size=AppGenericStore.ICON_SIZE,
                  global_icon_cache=True):
@@ -492,7 +496,7 @@ class AppListStore(Gtk.ListStore, AppGenericStore):
             self[(i,)][0] = doc
 
     def clear(self):
-        # reset the tranaction map because it will now be invalid
+        # reset the transaction map because it will now be invalid
         self.transaction_path_map = {}
         self.current_matches = None
         Gtk.ListStore.clear(self)
@@ -507,8 +511,8 @@ class AppTreeStore(Gtk.TreeStore, AppGenericStore):
         "needs-refresh": (GObject.SignalFlags.RUN_LAST,
                              None,
                              (str, ),
-                            ),
-        }
+                          ),
+    }
 
     def __init__(self, db, cache, icons, icon_size=AppGenericStore.ICON_SIZE,
                  global_icon_cache=True):
@@ -536,7 +540,7 @@ class AppTreeStore(Gtk.TreeStore, AppGenericStore):
         return it
 
     def set_nocategory_documents(self, documents, untranslated_name=None,
-        display_name=None):
+                                 display_name=None):
         category = UncategorisedRowRef(untranslated_name,
                                        display_name,
                                        len(documents))
@@ -545,6 +549,6 @@ class AppTreeStore(Gtk.TreeStore, AppGenericStore):
         return it
 
     def clear(self):
-        # reset the tranaction map because it will now be invalid
+        # reset the transaction map because it will now be invalid
         self.transaction_path_map = {}
         Gtk.TreeStore.clear(self)
