@@ -37,6 +37,7 @@ from softwarecenter.enums import (
     NonAppVisibility,
     DEFAULT_SEARCH_LIMIT,
     TransactionTypes,
+    PURCHASE_TRANSACTION_ID,
 )
 from softwarecenter.utils import (
     convert_desktop_file_to_installed_location,
@@ -58,8 +59,8 @@ from softwarecenter.utils import ExecutionTime
 
 from softwarecenter.backend.channel import SoftwareChannel
 from softwarecenter.backend.unitylauncher import (UnityLauncher,
-                                                  UnityLauncherInfo,
-                                                  TransactionDetails)
+                                                  UnityLauncherInfo)
+from softwarecenter.backend.zeitgeist_logger import ZeitgeistLogger
 
 LOG = logging.getLogger(__name__)
 
@@ -91,6 +92,58 @@ class AvailablePane(SoftwarePane):
                                                None,
                                                ())}
 
+    class TransactionDetails(object):
+        """ Simple class to keep track of aptdaemon transaction details """
+        def __init__(self, db, pkgname, appname, trans_id, trans_type):
+            self.db = db
+            self.app = Application(pkgname=pkgname, appname=appname)
+            self.trans_id = trans_id
+            self.trans_type = trans_type
+            self.__app_details = None
+            self.__real_desktop = None
+
+            if trans_type != TransactionTypes.INSTALL:
+                self.guess_final_desktop_file()
+
+        @property
+        def app_details(self):
+            if not self.__app_details:
+                self.__app_details = self.app.get_details(self.db)
+            return self.__app_details
+
+        @property
+        def desktop_file(self):
+            return self.app_details.desktop_file
+
+        @property
+        def final_desktop_file(self):
+            return self.guess_final_desktop_file()
+
+        def guess_final_desktop_file(self):
+            if self.__real_desktop:
+                return self.__real_desktop
+
+            # convert the app-install desktop file location to the actual installed
+            # desktop file location (or in the case of a purchased item from the
+            # agent, generate the correct installed desktop file location)
+            desktop_file = (
+                convert_desktop_file_to_installed_location(self.desktop_file,
+                                                           self.app.pkgname))
+            # we only add items to the launcher that have a desktop file
+            if not desktop_file:
+                return
+            # do not add apps that have no Exec entry in their desktop file
+            # (e.g. wine, see LP: #848437 or ubuntu-restricted-extras,
+            # see LP: #913756), also, don't add the item if NoDisplay is
+            # specified (see LP: #1006483)
+            if (os.path.exists(desktop_file) and
+                    (not get_exec_line_from_desktop(desktop_file) or
+                    is_no_display_desktop_file(desktop_file))):
+                return
+
+            self.__real_desktop = desktop_file
+            return self.__real_desktop
+
     def __init__(self,
                  cache,
                  db,
@@ -118,9 +171,9 @@ class AvailablePane(SoftwarePane):
 
         # integrate with the Unity launcher
         self.unity_launcher = UnityLauncher()
-        # keep track of applications that are queued to be added
-        # to the Unity launcher
-        self.unity_launcher_transaction_queue = {}
+
+        # keep track of transactions
+        self.transactions_queue = {}
 
     def init_view(self):
         if self.view_initialized:
@@ -212,17 +265,18 @@ class AvailablePane(SoftwarePane):
             Gtk.Label(label=NavButtons.PURCHASE))
 
         # install backend
+        # FIXME: move this out of the available pane really
         self.backend.connect("transaction-started",
             self.on_transaction_started)
         self.backend.connect("transactions-changed",
             self.on_transactions_changed)
         self.backend.connect("transaction-finished",
             self.on_transaction_complete)
-        self.backend.connect("transaction-cancelled",
-            self.on_transaction_cancelled)
         # a transaction error is treated the same as a cancellation
         self.backend.connect("transaction-stopped",
             self.on_transaction_cancelled)
+        self.backend.connect("transaction-cancelled",
+            self.on_transaction_cancelled)
 
         # now we are initialized
         self.searchentry.set_sensitive(True)
@@ -375,8 +429,23 @@ class AvailablePane(SoftwarePane):
 
     def on_transaction_started(self, backend, pkgname, appname, trans_id,
                                trans_type):
-        self._register_unity_launcher_transaction_started(pkgname, appname,
-                                                          trans_id, trans_type)
+        details = self.TransactionDetails(self.db, pkgname, appname, trans_id, trans_type)
+        self.transactions_queue[pkgname] = details
+
+        config = get_config()
+        if (trans_type == TransactionTypes.INSTALL and
+            trans_id != PURCHASE_TRANSACTION_ID and
+                config.add_to_unity_launcher and
+                softwarecenter.utils.is_unity_running()):
+            self._add_application_to_unity_launcher(details)
+
+    def on_transaction_cancelled(self, backend, result):
+        """ handle a transaction that has been cancelled
+        """
+        if result.pkgname:
+            self.unity_launcher.cancel_application_to_launcher(result.pkgname)
+        if result.pkgname in self.transactions_queue:
+            self.transactions_queue.pop(result.pkgname)
 
     def on_transactions_changed(self, backend, pending_transactions):
         """internal helper that keeps the action bar up-to-date by
@@ -385,92 +454,47 @@ class AvailablePane(SoftwarePane):
         if self._is_custom_list_search(self.state.search_term):
             self._update_action_bar()
 
-    def on_transaction_complete(self, backend, result):
-        """ handle a transaction that has completed successfully
-        """
-        if result.pkgname in self.unity_launcher_transaction_queue:
-            transaction_details = (
-                self.unity_launcher_transaction_queue.pop(result.pkgname))
-            self._add_application_to_unity_launcher(transaction_details)
-
-    def on_transaction_cancelled(self, backend, result):
-        """ handle a transaction that has been cancelled
-        """
-        if result.pkgname in self.unity_launcher_transaction_queue:
-            self.unity_launcher_transaction_queue.pop(result.pkgname)
-
-    def _register_unity_launcher_transaction_started(self, pkgname, appname,
-                                                     trans_id, trans_type):
-        # at the start of the transaction, we gather details for use later
-        # when it is time to add the installed app to the Unity launcher,
-        # (see #972710). we only care about installs for the launcher
-        # mvo: use softwarecenter.utils explicitly here so that we can monkey
-        #      patch it in the test
-        config = get_config()
-        if (trans_type == TransactionTypes.INSTALL and
-                config.add_to_unity_launcher and
-                softwarecenter.utils.is_unity_running()):
-            transaction_details = TransactionDetails(
-                    pkgname, appname, trans_id, trans_type)
-            self.unity_launcher_transaction_queue[pkgname] = (
-                    transaction_details)
-
-    def _add_application_to_unity_launcher(self, transaction_details):
-        app = Application(pkgname=transaction_details.pkgname,
-                          appname=transaction_details.appname)
-        appdetails = app.get_details(self.db)
-        # convert the app-install desktop file location to the actual installed
-        # desktop file location (or in the case of a purchased item from the
-        # agent, generate the correct installed desktop file location)
-        installed_desktop_file_path = (
-            convert_desktop_file_to_installed_location(appdetails.desktop_file,
-                                                       app.pkgname))
-        # we only add items to the launcher that have a desktop file
-        if not installed_desktop_file_path:
-            return
+    def _add_application_to_unity_launcher(self, trans_details):
         # do not add apps that have no Exec entry in their desktop file
         # (e.g. wine, see LP: #848437 or ubuntu-restricted-extras,
         # see LP: #913756), also, don't add the item if NoDisplay is
         # specified (see LP: #1006483)
-        if (os.path.exists(installed_desktop_file_path) and
-                (not get_exec_line_from_desktop(installed_desktop_file_path) or
-                 is_no_display_desktop_file(installed_desktop_file_path))):
+        if (os.path.exists(trans_details.desktop_file) and
+                (not get_exec_line_from_desktop(trans_details.desktop_file) or
+                 is_no_display_desktop_file(trans_details.desktop_file))):
             return
 
         # now gather up the unity launcher info items and send the app to the
         # launcher service
-        launcher_info = self._get_unity_launcher_info(app, appdetails,
-                installed_desktop_file_path,
-                transaction_details.trans_id)
+        launcher_info = self._get_unity_launcher_info(trans_details)
         self.unity_launcher.send_application_to_launcher(
-                transaction_details.pkgname,
-                launcher_info)
+            trans_details.app.pkgname, launcher_info)
 
-    def _get_unity_launcher_info(
-            self, app, appdetails, installed_desktop_file_path, trans_id):
+    def on_transaction_complete(self, backend, result):
+        """ handle a transaction that has completed successfully
+        """
+        if result.pkgname in self.transactions_queue:
+            details = self.transactions_queue.pop(result.pkgname)
+
+            if details.trans_type == TransactionTypes.INSTALL:
+                ZeitgeistLogger(self.distro).log_install_event(details.final_desktop_file)
+            elif details.trans_type == TransactionTypes.REMOVE:
+                ZeitgeistLogger(self.distro).log_uninstall_event(details.final_desktop_file)
+
+    def _get_unity_launcher_info(self, trans_details):
         (icon_size, icon_x, icon_y) = (
-                self._get_onscreen_icon_details_for_launcher_service(app))
+                self._get_onscreen_icon_details_for_launcher_service(trans_details.app))
         icon_path = get_file_path_from_iconname(
                                 self.icons,
-                                iconname=appdetails.icon)
-        # Note that the transaction ID is not specified because we are firing
-        # the dbus signal at the very end of the installation now, and the
-        # corresponding fix in Unity is expecting this value to be empty (it
-        # would not be useful to the Unity launcher at this point anyway,
-        # as the corresponding transaction would be complete).
-        # Please see bug LP: #925014 and corresponding Unity branch for
-        # further details.
-        # TODO: If and when we re-implement firing the dbus signal at the
-        # start of the transaction, at that time we will need to replace
-        # the empty string below with the trans_id value.
-        launcher_info = UnityLauncherInfo(app.name,
-                                          appdetails.icon,
+                                iconname=trans_details.app_details.icon)
+        launcher_info = UnityLauncherInfo(trans_details.app.name,
+                                          trans_details.app_details.icon,
                                           icon_path,
                                           icon_x,
                                           icon_y,
                                           icon_size,
-                                          installed_desktop_file_path,
-                                          "")
+                                          trans_details.desktop_file,
+                                          trans_details.trans_id)
         return launcher_info
 
     def _get_onscreen_icon_details_for_launcher_service(self, app):
