@@ -18,7 +18,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from gi.repository import GObject, Gtk, Gdk
+from gi.repository import GObject, Gtk, Gdk, GLib
 
 import datetime
 import gettext
@@ -109,7 +109,7 @@ class GRatingsAndReviews(GObject.GObject):
         # piston worker thread
         self.worker_thread = Worker(token)
         self.worker_thread.start()
-        GObject.timeout_add(500,
+        GLib.timeout_add(500,
                             self._check_thread_status,
                             None)
 
@@ -168,9 +168,11 @@ class Worker(threading.Thread):
         self._transmit_state = TRANSMIT_STATE_NONE
         self._transmit_error_str = ""
         self.display_name = "No display name"
-        auth = piston_mini_client.auth.OAuthAuthorizer(token["token"],
-           token["token_secret"], token["consumer_key"],
-           token["consumer_secret"])
+        auth = piston_mini_client.auth.OAuthAuthorizer(
+            token["token"],
+            token["token_secret"],
+            token["consumer_key"],
+            token["consumer_secret"])
         # change default server to the SSL one
         distro = get_distro()
         service_root = distro.REVIEWS_SERVER
@@ -200,11 +202,11 @@ class Worker(threading.Thread):
             self._submit_delete_if_pending()
             time.sleep(0.2)
             if (self._shutdown and
-                self.pending_reviews.empty() and
-                self.pending_usefulness.empty() and
-                self.pending_reports.empty() and
-                self.pending_modify.empty() and
-                self.pending_delete.empty()):
+                    self.pending_reviews.empty() and
+                    self.pending_usefulness.empty() and
+                    self.pending_reports.empty() and
+                    self.pending_modify.empty() and
+                    self.pending_delete.empty()):
                 return
 
     def _submit_usefulness_if_pending(self):
@@ -360,7 +362,7 @@ class Worker(threading.Thread):
 
     def verify_server_status(self):
         """ verify that the server we want to talk to can be reached
-            this method should be overriden if clients talk to a different
+            this method should be overridden if clients talk to a different
             server than rnr
         """
         try:
@@ -589,7 +591,7 @@ class SubmitReviewsApp(BaseApp):
     SUCCESS_MESSAGE = _("Review submitted")
 
     def __init__(self, app, version, iconname, origin, parent_xid, datadir,
-        action="submit", review_id=0):
+                 action="submit", review_id=0):
         BaseApp.__init__(self, datadir, "submit_review.ui")
         self.datadir = datadir
         # legal fineprint, do not change without consulting a lawyer
@@ -767,8 +769,8 @@ class SubmitReviewsApp(BaseApp):
         summary_chars = self.review_summary_entry.get_text_length()
         review_chars = self.review_buffer.get_char_count()
         if (summary_chars and summary_chars <= self.SUMMARY_CHAR_LIMITS[0] and
-            review_chars and review_chars <= self.REVIEW_CHAR_LIMITS[0] and
-            int(self.star_rating.get_rating()) > 0):
+                review_chars and review_chars <= self.REVIEW_CHAR_LIMITS[0] and
+                int(self.star_rating.get_rating()) > 0):
             self.button_post.set_sensitive(True)
             self._change_status("clear", "")
         else:
@@ -794,22 +796,23 @@ class SubmitReviewsApp(BaseApp):
         # perform an initial check on character counts to return False if any
         # don't match, avoids doing unnecessary string comparisons
         if (self.review_summary_entry.get_text_length() !=
-            len(self.orig_summary_text) or
-            self.review_buffer.get_char_count() != len(self.orig_review_text)):
+                len(self.orig_summary_text) or
+                self.review_buffer.get_char_count() !=
+                    len(self.orig_review_text)):
             return False
         #compare rating
         if self.star_rating.get_rating() != self.orig_star_rating:
             return False
         #compare summary text
         if (self.review_summary_entry.get_text().decode('utf-8') !=
-            self.orig_summary_text):
+                self.orig_summary_text):
             return False
         #compare review text
         if (self.review_buffer.get_text(
-            self.review_buffer.get_start_iter(),
-            self.review_buffer.get_end_iter(),
-            include_hidden_chars=False).decode('utf-8') !=
-            self.orig_review_text):
+                self.review_buffer.get_start_iter(),
+                self.review_buffer.get_end_iter(),
+                include_hidden_chars=False).decode('utf-8') !=
+                    self.orig_review_text):
             return False
         return True
 
@@ -989,7 +992,7 @@ class SubmitReviewsApp(BaseApp):
 
     def _confirm_cancellation(self):
         if (self._has_user_started_reviewing() and not
-            self._displaying_cancel_confirmation):
+                self._displaying_cancel_confirmation):
 
             def do_cancel(widget):
                 self.submit_window.destroy()
@@ -1135,11 +1138,10 @@ class SubmitReviewsApp(BaseApp):
         def _gwibber_message_string_from_data(appname, rating, summary, link):
             """ helper so that we do not duplicate the "reviewed..." string """
             return _("reviewed %(appname)s in Ubuntu: %(rating)s "
-                       "%(summary)s %(link)s") % {
-                'appname': appname,
-                'rating': rating,
-                'summary': summary,
-                'link': link}
+                       "%(summary)s %(link)s") % {'appname': appname,
+                                                  'rating': rating,
+                                                  'summary': summary,
+                                                  'link': link}
 
         rating = self.star_rating.get_rating()
         rating_string = ''
@@ -1153,7 +1155,7 @@ class SubmitReviewsApp(BaseApp):
 
         review_summary_text = self.review_summary_entry.get_text()
         # FIXME: currently the link is not useful (at all) for most
-        #        people not runnig ubuntu
+        #        people not running ubuntu
         #app_link = "http://apt.ubuntu.com/p/%s" % self.app.pkgname
         app_link = ""
         gwib_msg = _gwibber_message_string_from_data(
@@ -1166,7 +1168,7 @@ class SubmitReviewsApp(BaseApp):
             review_summary_text = (review_summary_text[:new_char_count] +
                 u"\u2026")
             gwib_msg = _gwibber_message_string_from_data(
-            self.app.name, rating_string, review_summary_text, app_link)
+                self.app.name, rating_string, review_summary_text, app_link)
 
         return gwib_msg
 
@@ -1242,7 +1244,7 @@ class ReportReviewApp(BaseApp):
 
     def _enable_or_disable_report_button(self, widget):
         if (self.textview_report.get_buffer().get_char_count() > 0 and
-            self.combobox_report_summary.get_active() != 0):
+                self.combobox_report_summary.get_active() != 0):
             self.button_post.set_sensitive(True)
         else:
             self.button_post.set_sensitive(False)
