@@ -58,7 +58,7 @@ def init_sc_css_provider(toplevel, settings, screen):
         # style provider
         if toplevel._css_provider._theme_name == theme_name:
             return
-        else:  # clean up old css provider if exixts
+        else:  # clean up old css provider if exists
             context.remove_provider_for_screen(screen, toplevel._css_provider)
 
     # munge css path for theme-name
