@@ -185,11 +185,11 @@ class PackageStatusBar(StatusBar):
         self.app_manager = get_appmanager()
 
         self.button.connect('clicked', self._on_button_clicked)
-        GObject.timeout_add(500, self._pulse_helper)
+        GLib.timeout_add(500, self._pulse_helper)
 
     def _pulse_helper(self):
         if (self.pkg_state == PkgStates.INSTALLING_PURCHASED and
-            self.progress.get_fraction() == 0.0):
+                self.progress.get_fraction() == 0.0):
             self.progress.pulse()
         return True
 
@@ -259,7 +259,7 @@ class PackageStatusBar(StatusBar):
         app_version = self.app_details.version
         # all available not-automatic (version, archive_suits)
         not_auto_suites = self.app_details.get_not_automatic_archive_versions()
-        # populat the combobox if
+        # populate the combobox if
         if not_auto_suites:
             combo = self.combo_multiple_versions
             combo.disconnect_by_func(self._on_combo_multiple_versions_changed)
@@ -367,15 +367,14 @@ class PackageStatusBar(StatusBar):
         elif state == PkgStates.NEEDS_PURCHASE:
             self.set_label("%s" % (app_details.price))
             if (app_details.hardware_requirements_satisfied and
-                app_details.region_requirements_satisfied):
+                    app_details.region_requirements_satisfied):
                 self.set_button_label(_(u'Buy\u2026'))
             else:
                 self.set_button_label(_(u'Buy Anyway\u2026'))
         elif state == PkgStates.FORCE_VERSION:
             self.set_button_label(_('Change'))
-        elif state in (
-            PkgStates.PURCHASED_BUT_REPO_MUST_BE_ENABLED,
-            PkgStates.PURCHASED_BUT_NOT_AVAILABLE_FOR_SERIES):
+        elif state in (PkgStates.PURCHASED_BUT_REPO_MUST_BE_ENABLED,
+                       PkgStates.PURCHASED_BUT_NOT_AVAILABLE_FOR_SERIES):
 
             # purchase_date is a string, must first convert to
             # datetime.datetime
@@ -403,7 +402,7 @@ class PackageStatusBar(StatusBar):
                 # TRANSLATORS: Free here means Gratis
                 self.set_label(_("Free"))
             if (app_details.hardware_requirements_satisfied and
-                app_details.region_requirements_satisfied):
+                    app_details.region_requirements_satisfied):
                 self.set_button_label(_('Install'))
             else:
                 self.set_button_label(_('Install Anyway'))
@@ -438,7 +437,7 @@ class PackageStatusBar(StatusBar):
                 self.set_button_label(_("Use This Source"))
             else:
                 # FIXME: This will currently not be displayed,
-                #        because we don't differenciate between
+                #        because we don't differentiate between
                 #        components that are not enabled or that just
                 #        lack the "Packages" files (but are in sources.list)
                 self.set_button_label(_("Update Now"))
@@ -613,7 +612,7 @@ class AddonsTable(Gtk.VBox):
     __gsignals__ = {'table-built': (GObject.SignalFlags.RUN_FIRST,
                                     None,
                                     ()),
-                   }
+                    }
 
     def __init__(self, addons_manager):
         Gtk.VBox.__init__(self)
@@ -629,7 +628,7 @@ class AddonsTable(Gtk.VBox):
         self.label = Gtk.Label()
         self.label.set_alignment(0, 0.5)
 
-        markup = '<big><b>%s</b></big>' % _('Add-ons')
+        markup = '<big><b>%s</b></big>' % _('Optional add-ons')
         self.label.set_markup(markup)
         self.pack_start(self.label, False, False, 0)
 
@@ -708,7 +707,7 @@ class AddonsStatusBar(StatusBar):
         # FIXME: addons are not always free, but the old implementation
         #        of determining price was buggy
         if (not self.addons_manager.addons_to_install and
-            not self.addons_manager.addons_to_remove):
+                not self.addons_manager.addons_to_remove):
             self.hide()
         else:
             sensitive = network_state_is_connected()
@@ -908,7 +907,7 @@ class AppDetailsView(Viewport):
         if state in NetState.NM_STATE_DISCONNECTED_LIST:
             self._check_for_reviews()
         elif state in NetState.NM_STATE_CONNECTED_LIST:
-            GObject.timeout_add(500, self._check_for_reviews)
+            GLib.timeout_add(500, self._check_for_reviews)
 
         # set addon table and action button states based on sensitivity
         sensitive = state in NetState.NM_STATE_CONNECTED_LIST
@@ -930,7 +929,7 @@ class AppDetailsView(Viewport):
         # (LP: #742635)
         if not self.app:
             return
-        # review stats is fast and syncronous
+        # review stats is fast and synchronous
         stats = self.review_loader.get_review_stats(self.app)
         self._update_review_stats_widget(stats)
         # individual reviews is slow and async so we just queue it here
@@ -1440,10 +1439,10 @@ class AppDetailsView(Viewport):
         self.desktop_file = app_details.desktop_file
         # only enable test drive if we have a desktop file and exec line
         if (not self.weblive.ready or
-            not self.weblive.is_pkgname_available_on_server(
-                app_details.pkgname) or
-            not os.path.exists(self.desktop_file) or
-            not get_exec_line_from_desktop(self.desktop_file)):
+                not self.weblive.is_pkgname_available_on_server(
+                    app_details.pkgname) or
+                not os.path.exists(self.desktop_file) or
+                not get_exec_line_from_desktop(self.desktop_file)):
             self.test_drive.hide()
         else:
             self.test_drive.show()
@@ -1455,7 +1454,7 @@ class AppDetailsView(Viewport):
             self.pkg_warningbar.label.set_text(app_details.error)
             return
         if (app_details.hardware_requirements_satisfied and
-            app_details.region_requirements_satisfied):
+                app_details.region_requirements_satisfied):
             self.pkg_warningbar.hide()
         else:
             s = get_hw_missing_long_description(
@@ -1476,11 +1475,11 @@ class AppDetailsView(Viewport):
             version = utf8(_("%s (unknown version)")) % utf8(
                 app_details.pkgname)
         if app_details.license:
-            license = GObject.markup_escape_text(app_details.license)
+            license = GLib.markup_escape_text(app_details.license)
         else:
             license = _("Unknown")
         if app_details.maintenance_status:
-            support = GObject.markup_escape_text(
+            support = GLib.markup_escape_text(
                 app_details.maintenance_status)
         else:
             support = _("Unknown")
@@ -1526,12 +1525,12 @@ class AppDetailsView(Viewport):
         pkg_ambiguous_error = app_details.pkg_state in (PkgStates.NOT_FOUND,
                                                         PkgStates.NEEDS_SOURCE)
 
-        appname = GObject.markup_escape_text(app_details.display_name)
+        appname = GLib.markup_escape_text(app_details.display_name)
 
         if app_details.pkg_state == PkgStates.NOT_FOUND:
             summary = app_details._error_not_found
         else:
-            summary = GObject.markup_escape_text(app_details.display_summary)
+            summary = GLib.markup_escape_text(app_details.display_summary)
         if not summary:
             summary = ""
 
@@ -1730,7 +1729,7 @@ class AppDetailsView(Viewport):
             # no longer in this state
             for state in [PkgStates.NEEDS_SOURCE, PkgStates.NOT_FOUND]:
                 if (self.pkg_state == state and
-                    self.app_details.pkg_state != state):
+                        self.app_details.pkg_state != state):
                     force = True
         self.pkg_state = self.app_details.pkg_state
 
@@ -1761,8 +1760,8 @@ class AppDetailsView(Viewport):
     # common code
     def _review_write_new(self):
         if (not self.app or
-            not self.app.pkgname in self.cache or
-            not self.cache[self.app.pkgname].candidate):
+                not self.app.pkgname in self.cache or
+                not self.cache[self.app.pkgname].candidate):
             dialogs.error(None,
                           _("Version unknown"),
                           _("The version of the application can not "
@@ -1830,8 +1829,8 @@ class AppDetailsView(Viewport):
 
         # handle purchase: install purchased has multiple steps
         if (state == PkgStates.INSTALLING_PURCHASED and
-            result and
-            not result.pkgname):
+                result and
+                not result.pkgname):
             self.pkg_statusbar.configure(self.app_details,
                 PkgStates.INSTALLING_PURCHASED)
         elif (state == PkgStates.INSTALLING_PURCHASED and
@@ -1906,8 +1905,8 @@ class AppDetailsView(Viewport):
 
     def _on_transaction_progress_changed(self, backend, pkgname, progress):
         if (self.app_details and
-            self.app_details.pkgname and
-            self.app_details.pkgname == pkgname):
+                self.app_details.pkgname and
+                self.app_details.pkgname == pkgname):
             if not self.pkg_statusbar.progress.get_property('visible'):
                 self.pkg_statusbar.button.hide()
                 self.pkg_statusbar.combo_multiple_versions.hide()
@@ -1947,18 +1946,18 @@ class AppDetailsView(Viewport):
             position cannot be determined for any reason, then the value (0,0)
             is returned
         """
-        # find toplevel parent
+        # find top-level parent
         parent = self
         while parent.get_parent():
             parent = parent.get_parent()
-        # get x, y relative to toplevel
+        # get x, y relative to top-level
         try:
             (x, y) = self.icon.translate_coordinates(parent, 0, 0)
         except Exception as e:
             LOG.warning("couldn't translate icon coordinates on-screen "
                         "for unity dbus message: %s" % e)
             return (0, 0)
-        # get toplevel window position
+        # get top-level window position
         (px, py) = parent.get_position()
         return (px + x, py + y)
 
@@ -2004,6 +2003,16 @@ class AppDetailsView(Viewport):
         if not self.totalsize_info.get_property('visible'):
             return False
 
+        # if we need to purchase/enable the report use the agent info
+        if self.app_details.pkg_state in (
+                PkgStates.NEEDS_SOURCE,
+                PkgStates.NEEDS_PURCHASE,
+                PkgStates.PURCHASED_BUT_REPO_MUST_BE_ENABLED):
+            if self.app_details.size:
+                self.totalsize_info.set_value(
+                    GLib.format_size(self.app_details.size))
+                return
+
         self.totalsize_info.set_value(_("Calculating..."))
 
         while Gtk.events_pending():
@@ -2024,8 +2033,8 @@ class AppDetailsView(Viewport):
             return
         label_string = ""
         if (total_download_size == 0 and
-            total_install_size == 0 and
-            isinstance(self.app, DebFileApplication)):
+                total_install_size == 0 and
+                isinstance(self.app, DebFileApplication)):
             total_install_size = self.app_details.installed_size
         if total_download_size > 0:
             download_size = GLib.format_size(total_download_size)
@@ -2034,10 +2043,10 @@ class AppDetailsView(Viewport):
             install_size = GLib.format_size(total_install_size)
             label_string += _("%s when installed") % (install_size)
         elif (total_install_size == 0 and
-              self.app_details and
-              self.app_details.pkg_state == PkgStates.INSTALLED and
-              not self.addons_manager.addons_to_install and
-              not self.addons_manager.addons_to_remove):
+                  self.app_details and
+                  self.app_details.pkg_state == PkgStates.INSTALLED and
+                  not self.addons_manager.addons_to_install and
+                  not self.addons_manager.addons_to_remove):
             pkg_version = self.cache[self.app_details.pkgname].installed
             # we may not always get a pkg_version returned (LP: #870822),
             # in that case, we'll just have to display "Unknown"
