@@ -42,19 +42,20 @@ class AppView(Gtk.VBox):
         "application-activated": (GObject.SignalFlags.RUN_LAST,
                                   None,
                                   (GObject.TYPE_PYOBJECT, ),
-                                 ),
+                                  ),
         "application-selected": (GObject.SignalFlags.RUN_LAST,
                                   None,
                                   (GObject.TYPE_PYOBJECT, ),
                                  ),
-        }
+    }
 
     (INSTALLED_MODE, AVAILABLE_MODE, DIFF_MODE) = range(3)
 
     _SORT_METHOD_INDEX = (SortMethods.BY_ALPHABET,
                           SortMethods.BY_TOP_RATED,
                           SortMethods.BY_CATALOGED_TIME,
-                          SortMethods.BY_SEARCH_RANKING,)
+                          SortMethods.BY_SEARCH_RANKING,
+                          )
 
     # indices that relate to the above tuple
     _SORT_BY_ALPHABET = 0
@@ -184,7 +185,7 @@ class AppView(Gtk.VBox):
         # FIXME: installedpane handles display of the trees intimately,
         # so for the time being lets just return None in the case of our
         # TreeView displaying an AppTreeStore ...    ;(
-        # ... also we dont currently support user sorting in the
+        # ... also we don't currently support user sorting in the
         # installedview, so issue is somewhat moot for the time being...
         if isinstance(self.get_model(), AppTreeStore):
             LOG.debug("display_matches called on AppTreeStore, ignoring")
@@ -259,7 +260,7 @@ class AppView(Gtk.VBox):
         """
         icon_size = 32
         if (self.tree_view.selected_row_renderer and
-            self.tree_view.selected_row_renderer.icon):
+                self.tree_view.selected_row_renderer.icon):
             pb = self.tree_view.selected_row_renderer.icon
             if pb.get_width() > pb.get_height():
                 icon_size = pb.get_width()
@@ -271,11 +272,11 @@ class AppView(Gtk.VBox):
         """ helper for unity dbus support to get the x,y position of
             the application icon as it is displayed on-screen
         """
-        # find toplevel parent
+        # find top-level parent
         parent = self
         while parent.get_parent():
             parent = parent.get_parent()
-        # get toplevel window position
+        # get top-level window position
         (px, py) = parent.get_position()
         # and return the coordinate values
         if self.tree_view.selected_row_renderer:
