@@ -1,4 +1,4 @@
-from gi.repository import Gtk, Gdk, GObject
+from gi.repository import Gtk, Gdk, GLib
 import logging
 
 from gettext import gettext as _
@@ -171,7 +171,7 @@ class AppTreeView(Gtk.TreeView):
         if old is not None:
             start, end = self.get_visible_range() or (None, None)
             if ((start and start.compare(old) != -1) or
-                (end and end.compare(old) != 1)):
+                    (end and end.compare(old) != 1)):
                 self._needs_collapse.append(old)
             else:
                 try:  # try... a lazy solution to Bug #846204
@@ -263,7 +263,7 @@ class AppTreeView(Gtk.TreeView):
         model = tree.get_model()
         app = model[path[0]][AppGenericStore.COL_ROW_DATA]
         if (not network_state_is_connected() and
-            not self.appmodel.is_installed(app)):
+                not self.appmodel.is_installed(app)):
             for btn_id in self.ACTION_BTNS:
                 btn_id = tr.get_button_by_name(CellButtonIDs.ACTION)
                 btn_id.set_sensitive(False)
@@ -437,7 +437,7 @@ class AppTreeView(Gtk.TreeView):
         x, y = int(event.x), int(event.y)
         for btn in tr.get_buttons():
             if (btn.point_in(x, y) and
-                (btn.state != Gtk.StateFlags.INSENSITIVE)):
+                    (btn.state != Gtk.StateFlags.INSENSITIVE)):
                 self.focal_btn = btn
                 btn.set_state(Gtk.StateFlags.ACTIVE)
                 view.queue_draw()
@@ -453,7 +453,7 @@ class AppTreeView(Gtk.TreeView):
         x, y = int(event.x), int(event.y)
         for btn in tr.get_buttons():
             if (btn.point_in(x, y) and
-                (btn.state != Gtk.StateFlags.INSENSITIVE)):
+                    (btn.state != Gtk.StateFlags.INSENSITIVE)):
                 btn.set_state(Gtk.StateFlags.NORMAL)
                 self.get_window().set_cursor(self._cursor_hand)
                 if self.focal_btn is not btn:
@@ -485,7 +485,7 @@ class AppTreeView(Gtk.TreeView):
         elif kv == Gdk.KEY_space:  # spacebar
             for btn in tr.get_buttons():
                 if (btn is not None and btn.has_focus and
-                    btn.state != Gtk.StateFlags.INSENSITIVE):
+                        btn.state != Gtk.StateFlags.INSENSITIVE):
                     btn.set_state(Gtk.StateFlags.ACTIVE)
                     sel = self.get_selection()
                     model, it = sel.get_selected()
@@ -520,7 +520,7 @@ class AppTreeView(Gtk.TreeView):
     def _init_activated(self, btn, model, path):
         app = model[path][AppGenericStore.COL_ROW_DATA]
         s = Gtk.Settings.get_default()
-        GObject.timeout_add(s.get_property("gtk-timeout-initial"),
+        GLib.timeout_add(s.get_property("gtk-timeout-initial"),
                             self._app_activated_cb,
                             btn,
                             btn.name,
@@ -575,7 +575,7 @@ class AppTreeView(Gtk.TreeView):
             btn.set_sensitive(False)
             model.row_changed(path, model.get_iter(path))
             app_manager = get_appmanager()
-            # be sure we dont request an action for a pkg with
+            # be sure we don't request an action for a pkg with
             # pre-existing actions
             if pkgname in self._action_block_list:
                 logging.debug("Action already in progress for package:"
@@ -607,7 +607,7 @@ class AppTreeView(Gtk.TreeView):
                 window.set_cursor(cursor)
 
     def _on_transaction_started(self, backend, pkgname, appname, trans_id,
-        trans_type, tr):
+                                trans_type, tr):
         """callback when an application install/remove transaction has
         started
         """
