@@ -18,7 +18,7 @@
 
 import cairo
 
-from gi.repository import Gtk, Gdk, Pango, GObject, GdkPixbuf
+from gi.repository import Gtk, Gdk, Pango, GObject, GdkPixbuf, GLib
 from gettext import gettext as _
 
 from softwarecenter.backend.installbackend import get_install_backend
@@ -197,7 +197,7 @@ class FeaturedTile(TileButton):
         self.content_left.pack_start(self.image, False, False, 0)
 
         self.title = Gtk.Label.new(self._MARKUP %
-            GObject.markup_escape_text(label))
+            GLib.markup_escape_text(label))
         self.title.set_alignment(0.0, 0.5)
         self.title.set_use_markup(True)
         self.title.set_tooltip_text(label)
@@ -207,7 +207,7 @@ class FeaturedTile(TileButton):
         categories = helper.get_categories(doc)
         if categories is not None:
             self.category = Gtk.Label.new('<span font_desc="%i">%s</span>' %
-                (em(0.6), GObject.markup_escape_text(categories)))
+                (em(0.6), GLib.markup_escape_text(categories)))
             self.category.set_use_markup(True)
             self.category.set_alignment(0.0, 0.5)
             self.category.set_ellipsize(Pango.EllipsizeMode.END)
@@ -476,8 +476,8 @@ class SectionSelector(TileToggleButton):
         alloc = self.get_allocation()
 
         if (self._alloc is None or
-            self._alloc.width != alloc.width or
-            self._alloc.height != alloc.height):
+                self._alloc.width != alloc.width or
+                self._alloc.height != alloc.height):
             self._alloc = alloc
             # reset the bg cache
             self._bg_cache = {}
@@ -544,7 +544,7 @@ class Link(Gtk.Label):
         "clicked": (GObject.SignalFlags.RUN_LAST,
                     None,
                     (),)
-        }
+    }
 
     def __init__(self, markup="", uri="none"):
         Gtk.Label.__init__(self)
