@@ -17,7 +17,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from gi.repository import Gtk, Gdk, GObject, Pango
+from gi.repository import Gtk, Gdk, GObject, GLib, Pango
 
 from softwarecenter.utils import utf8
 from softwarecenter.ui.gtk3.em import EM
@@ -122,7 +122,7 @@ class CellRendererAppView(Gtk.CellRendererText):
         Gtk.render_layout(context, cr, x, y, layout)
 
     def _render_price(self, context, cr, app, layout, cell_area, xpad, ypad,
-        is_rtl):
+                      is_rtl):
         layout.set_markup("%s" % self.model.get_display_price(app))
 
         if is_rtl:
@@ -180,7 +180,7 @@ class CellRendererAppView(Gtk.CellRendererText):
             max_layout_width -= star_width + 6 * xpad
 
         if (self.props.isactive and
-            self.model.get_transaction_progress(app) > 0):
+                self.model.get_transaction_progress(app) > 0):
             action_btn = self.get_button_by_name(CellButtonIDs.ACTION)
             max_layout_width -= (xpad + action_btn.width)
 
@@ -275,7 +275,7 @@ class CellRendererAppView(Gtk.CellRendererText):
         context.restore()
 
     def _render_buttons(self, context, cr, cell_area, layout, xpad, ypad,
-        is_rtl):
+                        is_rtl):
 
         # layout buttons and paint
         y = cell_area.y + cell_area.height - ypad
@@ -469,7 +469,7 @@ class CellButtonRenderer(object):
         max_size = (0, 0)
 
         for k, variant in self.markup_variants.items():
-            safe_markup = GObject.markup_escape_text(utf8(variant))
+            safe_markup = GLib.markup_escape_text(utf8(variant))
             layout.set_markup(safe_markup, -1)
             size = layout.get_size()
             max_size = max(max_size, size)
