@@ -4,7 +4,7 @@ from math import pi as PI
 PI_OVER_180 = PI / 180
 import softwarecenter.paths
 
-from gi.repository import Gtk, Gdk, GObject
+from gi.repository import Gtk, Gdk, GObject, GLib
 
 from buttons import MoreLink
 from softwarecenter.ui.gtk3.em import StockEms
@@ -138,16 +138,16 @@ class FlowableGrid(Gtk.Fixed):
         a = self.get_allocation()
         w = a.width / self.n_columns
 
-        for i in range(self.n_columns):
+        for i in range(1, self.n_columns):
             cr.move_to(i * w + 0.5, 0)
-            cr.rel_line_to(0, a.height - 3)
+            cr.rel_line_to(0, a.height - 1)
             cr.stroke()
 
         w = a.height / self.n_rows
 
         for i in range(self.n_rows):
-            cr.move_to(2, i * w + 0.5)
-            cr.rel_line_to(a.width - 4, 0)
+            cr.move_to(0, i * w + 0.5)
+            cr.rel_line_to(a.width, 0)
             cr.stroke()
 
         cr.restore()
@@ -196,8 +196,8 @@ class TileGrid(FlowableGrid):
         "application-activated": (GObject.SignalFlags.RUN_LAST,
                                   None,
                                   (GObject.TYPE_PYOBJECT, ),
-                                 ),
-        }
+                                  ),
+    }
 
     def add_tiles(self, properties_helper, docs, amount):
         '''Adds application tiles to an ApplicationTileGrid:
@@ -219,7 +219,7 @@ class TileGrid(FlowableGrid):
             self.emit("application-activated", app)
             return False
 
-        GObject.timeout_add(50, timeout_emit)
+        GLib.timeout_add(50, timeout_emit)
 
 
 # first tier of caching, cache component assets from which frames are
@@ -239,7 +239,7 @@ class Frame(Gtk.Alignment):
         # set padding + some additional padding to factor in the
         # dropshadow+border width
         # padding is (top, bottom, left, right)
-        self.set_padding(padding, padding + 2, padding + 3, padding + 3)
+        self.set_padding(padding, padding + 3, padding + 3, padding + 3)
 
         self._cache_art_assets()
         # second tier of caching, cache resultant surface of
@@ -341,6 +341,7 @@ class Frame(Gtk.Alignment):
         # we cache as much of the drawing as possible
         # store a copy of the rendered frame surface, so we only have to
         # do a full redraw if the widget dimensions change
+
         if self._frame_surface_cache is None:
             surf = cairo.ImageSurface(cairo.FORMAT_ARGB32, a.width, a.height)
             _cr = cairo.Context(surf)
@@ -450,7 +451,7 @@ class SmallBorderRadiusFrame(Frame):
 class FramedBox(Frame):
 
     def __init__(self, orientation=Gtk.Orientation.VERTICAL, spacing=0,
-        padding=0):
+                 padding=0):
         Frame.__init__(self, padding)
         self.box = Gtk.Box.new(orientation, spacing)
         Gtk.Alignment.add(self, self.box)
@@ -582,7 +583,7 @@ class FramedHeaderBox(FramedBox):
 
             else:
                 x = ta.x - a.x - StockEms.MEDIUM
-                w = ta.width + StockEms.MEDIUM - 1
+                w = ta.width + StockEms.MEDIUM + 3
 
                 cr.move_to(x, y)
                 cr.arc(x + w - r, y + r, r, 270 * PI_OVER_180, 0)
