@@ -24,6 +24,7 @@ from gettext import gettext as _
 
 from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import GdkPixbuf
 from gi.repository import WebKit
@@ -106,8 +107,8 @@ class _HtmlRenderer(Gtk.OffscreenWindow):
         "render-finished": (GObject.SignalFlags.RUN_LAST,
                             None,
                             (),
-                           )
-        }
+                            )
+    }
 
     def __init__(self):
         Gtk.OffscreenWindow.__init__(self)
@@ -178,8 +179,8 @@ class _HtmlRenderer(Gtk.OffscreenWindow):
         """Called when the rendering of the html banner is done"""
         if view.get_property("load-status") == WebKit.LoadStatus.FINISHED:
             # this needs to run with a timeout because otherwise the
-            # status is emited before the offscreen image is finihsed
-            GObject.timeout_add(100, lambda: self.emit("render-finished"))
+            # status is emitted before the offscreen image is finished
+            GLib.timeout_add(100, lambda: self.emit("render-finished"))
 
 
 class ExhibitButton(Gtk.Button):
@@ -199,8 +200,8 @@ class ExhibitButton(Gtk.Button):
     def on_size_allocate(self, *args):
         a = self.get_allocation()
         if (self._dropshadow is not None and
-            a.width == self._dropshadow.get_width() and
-            a.height == self._dropshadow.get_height()):
+                a.width == self._dropshadow.get_width() and
+                a.height == self._dropshadow.get_height()):
             return
 
         self._dropshadow = self.DROPSHADOW.scale_simple(
@@ -261,8 +262,8 @@ class ExhibitBanner(Gtk.EventBox):
         "show-exhibits-clicked": (GObject.SignalFlags.RUN_LAST,
                                   None,
                                   (GObject.TYPE_PYOBJECT,),
-                                 )
-        }
+                                  )
+    }
 
     DROPSHADOW_HEIGHT = 11
     MAX_HEIGHT = 200  # pixels
@@ -372,20 +373,20 @@ class ExhibitBanner(Gtk.EventBox):
     def on_key_press(self, widget, event):
         # activate
         if (event.keyval == Gdk.keyval_from_name("space") or
-            event.keyval == Gdk.keyval_from_name("Return") or
-            event.keyval == Gdk.keyval_from_name("KP_Enter")):
+                event.keyval == Gdk.keyval_from_name("Return") or
+                event.keyval == Gdk.keyval_from_name("KP_Enter")):
             exhibit = self.exhibits[self.cursor]
             if exhibit.package_names:
                 self.emit("show-exhibits-clicked", exhibit)
             return True
         # previous
         if (event.keyval == Gdk.keyval_from_name("Left") or
-            event.keyval == Gdk.keyval_from_name("KP_Left")):
+                event.keyval == Gdk.keyval_from_name("KP_Left")):
             self.on_previous_clicked()
             return True
         # next
         if (event.keyval == Gdk.keyval_from_name("Right") or
-            event.keyval == Gdk.keyval_from_name("KP_Right")):
+                event.keyval == Gdk.keyval_from_name("KP_Right")):
             self.on_next_clicked()
             return True
         return False
@@ -400,7 +401,7 @@ class ExhibitBanner(Gtk.EventBox):
 
     def cleanup_timeout(self):
         if self._timeout > 0:
-            GObject.source_remove(self._timeout)
+            GLib.source_remove(self._timeout)
             self._timeout = 0
 
     def _render_exhibit_at_cursor(self):
@@ -414,7 +415,7 @@ class ExhibitBanner(Gtk.EventBox):
         # copy old image for the fade
         if self.image:
             self.old_image = self.image.copy()
-        # set the rigth one
+        # set the right one
         self.renderer.set_exhibit(self.exhibits[cursor])
         # make sure the active button is having a different color
         for i, w in enumerate(self.index_hbox):
@@ -443,7 +444,7 @@ class ExhibitBanner(Gtk.EventBox):
 
     def queue_next(self):
         self.cleanup_timeout()
-        self._timeout = GObject.timeout_add_seconds(
+        self._timeout = GLib.timeout_add_seconds(
                                     self.TIMEOUT_SECONDS, self.next_exhibit)
         return self._timeout
 
@@ -453,7 +454,7 @@ class ExhibitBanner(Gtk.EventBox):
         if self.image.get_width() == 1:
             # the offscreen window is not really as such content not
             # correctly rendered
-            GObject.timeout_add(500, self.on_banner_rendered, renderer)
+            GLib.timeout_add(500, self.on_banner_rendered, renderer)
             return
 
         from gi.repository import Atk
@@ -479,7 +480,7 @@ class ExhibitBanner(Gtk.EventBox):
             self.queue_draw()
             return retval
 
-        GObject.timeout_add(50, fade_step)
+        GLib.timeout_add(50, fade_step)
 
     def _cache_art_assets(self):
         global _asset_cache
@@ -576,7 +577,7 @@ class ExhibitBanner(Gtk.EventBox):
             self.propagate_draw(child, cr)
 
     def _init_pause_handling_if_needed(self):
-        # nothing todo if we have the toplevel already
+        # nothing to do if we have the toplevel already
         if self._toplevel_window:
             return
         # find toplevel Gtk.Window
@@ -612,7 +613,7 @@ class ExhibitBanner(Gtk.EventBox):
             child.destroy()
 
         for sigid in self._dotsigs:
-            GObject.source_remove(sigid)
+            GLib.source_remove(sigid)
 
         self._dotsigs = []
         if len(self.exhibits) > 1:
