@@ -17,7 +17,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from gi.repository import Gtk, GObject
+from gi.repository import Gtk, GObject, GLib
 import logging
 
 from gettext import gettext as _
@@ -38,7 +38,7 @@ from softwarecenter.enums import (
     SOFTWARE_CENTER_NAME_KEYRING,
     RecommenderFeedbackActions,
     TransactionTypes,
-    )
+)
 from softwarecenter.utils import utf8
 from softwarecenter.netstatus import network_state_is_connected
 
@@ -54,8 +54,8 @@ class RecommendationsPanel(FramedHeaderBox):
         "application-activated": (GObject.SIGNAL_RUN_LAST,
                                   GObject.TYPE_NONE,
                                   (GObject.TYPE_PYOBJECT,),
-                                 ),
-        }
+                                  ),
+    }
 
     def __init__(self):
         FramedHeaderBox.__init__(self)
@@ -89,7 +89,7 @@ class RecommendationsPanel(FramedHeaderBox):
     def _on_transaction_started(self, backend, pkgname, appname, trans_id,
                                 trans_type):
         if (trans_type != TransactionTypes.INSTALL and
-            pkgname in self.recommended_apps_viewed):
+                pkgname in self.recommended_apps_viewed):
             # if the transaction is not an installation we don't want to
             # track it as a recommended item
             self.recommended_apps_viewed.remove(pkgname)
@@ -124,8 +124,8 @@ class RecommendationsPanelCategory(RecommendationsPanel):
         "more-button-clicked": (GObject.SignalFlags.RUN_LAST,
                                 None,
                                 (GObject.TYPE_PYOBJECT, ),
-                               ),
-        }
+                                ),
+    }
 
     def __init__(self, db, properties_helper, subcategory):
         RecommendationsPanel.__init__(self)
@@ -133,7 +133,7 @@ class RecommendationsPanelCategory(RecommendationsPanel):
         self.properties_helper = properties_helper
         self.subcategory = subcategory
         if self.subcategory:
-            self.set_header_label(GObject.markup_escape_text(utf8(
+            self.set_header_label(GLib.markup_escape_text(utf8(
                 _("Recommended For You in %s")) % utf8(self.subcategory.name)))
         self.recommended_for_you_content = None
         if self.recommender_agent.is_opted_in():
@@ -167,7 +167,7 @@ class RecommendationsPanelCategory(RecommendationsPanel):
                           self._on_more_button_clicked,
                           self.recommended_for_you_cat)
         docs = cat.get_documents(self.db)
-        # display the recommendedations
+        # display the recommendations
         if len(docs) > 0:
             self.recommended_for_you_content.add_tiles(
                     self.properties_helper,
@@ -195,12 +195,12 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
         "recommendations-opt-in": (GObject.SIGNAL_RUN_LAST,
                                    GObject.TYPE_NONE,
                                    (),
-                                  ),
+                                   ),
         "recommendations-opt-out": (GObject.SIGNAL_RUN_LAST,
                                     GObject.TYPE_NONE,
                                     (),
-                                   ),
-        }
+                                    ),
+    }
 
     TURN_ON_RECOMMENDATIONS_TEXT = _(u"Turn On Recommendations")
     RECOMMENDATIONS_OPT_IN_TEXT = _(u"To make recommendations, "
