@@ -8,6 +8,8 @@ class HBar(Gtk.VBox):
         context = self.get_style_context()
         context.add_class("item-view-separator")
         self.connect("style-updated", self.on_style_updated)
+        # workaround broken engines (LP: #1021308)
+        self.emit("style-updated")
         return
 
     def on_style_updated(self, widget):
@@ -33,3 +35,5 @@ class HBar(Gtk.VBox):
         cr.set_line_width(2 * width)
         cr.stroke()
         cr.restore()
+        for child in self:
+            self.propagate_draw(child, cr)
