@@ -20,7 +20,7 @@ import cairo
 import os
 
 from math import pi as PI
-from gi.repository import Gtk, Gdk, GObject, PangoCairo
+from gi.repository import Gtk, Gdk, GLib, PangoCairo
 
 import softwarecenter.paths
 from softwarecenter.ui.gtk3.em import em
@@ -112,7 +112,7 @@ class RotationAboutCenterAnimation(object):
 
     def start(self):
         if not self.is_animating():
-            self.animator = GObject.timeout_add(self.NEW_FRAME_DELAY,
+            self.animator = GLib.timeout_add(self.NEW_FRAME_DELAY,
                                                 self.new_frame)
 
     def stop(self):
