@@ -18,7 +18,7 @@
 
 import gi
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, Gdk, Atk, Gio, GObject, GdkPixbuf
+from gi.repository import Gtk, Gdk, Atk, Gio, GObject, GdkPixbuf, GLib
 
 import logging
 
@@ -45,7 +45,7 @@ class ScreenshotData(GObject.GObject):
 
     def set_app_details(self, app_details):
         if self._sig > 0:
-            GObject.source_remove(self._sig)
+            GLib.source_remove(self._sig)
 
         self.app_details = app_details
         self.appname = app_details.display_name
@@ -237,19 +237,21 @@ class ScreenshotGallery(Gtk.VBox):
 
     def _on_key_press(self, widget, event):
         # react to spacebar, enter, numpad-enter
-        if (event.keyval in (Gdk.KEY_space, Gdk.KEY_Return,
-            Gdk.KEY_KP_Enter) and self.get_is_actionable()):
+        if (event.keyval in (
+                Gdk.KEY_space, Gdk.KEY_Return, Gdk.KEY_KP_Enter) and
+                self.get_is_actionable()):
             self.set_state(Gtk.StateType.ACTIVE)
 
     def _on_key_release(self, widget, event):
         # react to spacebar, enter, numpad-enter
         if (event.keyval in (Gdk.KEY_space, Gdk.KEY_Return,
-            Gdk.KEY_KP_Enter) and self.get_is_actionable()):
+                             Gdk.KEY_KP_Enter) and
+                self.get_is_actionable()):
             self.set_state(Gtk.StateType.NORMAL)
             self._show_image_dialog()
 
     def _show_image_dialog(self):
-        """ Displays the large screenshot in a seperate dialog window """
+        """ Displays the large screenshot in a separate dialog window """
 
         if self.data and self.screenshot_pixbuf:
             title = _("%s - Screenshot") % self.data.appname
@@ -301,7 +303,7 @@ class ScreenshotGallery(Gtk.VBox):
         self.loader.download_file(url, use_cache=self.USE_CACHING)
 
     def clear(self):
-        """ All state trackers are set to their intitial states, and
+        """ All state trackers are set to their initial states, and
             the old screenshot is cleared from the view.
         """
         self._height = 0
@@ -385,7 +387,7 @@ class Thumbnail(Gtk.Button):
         self.id_ = id_
 
         def download_complete_cb(loader, path):
-            width, height = ThumbnailGallery.THUMBNAIL_SIZE_CONTRAINTS
+            width, height = ThumbnailGallery.THUMBNAIL_SIZE_CONSTRAINTS
             pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
                         path,
                         width, height,  # width, height constraints
@@ -418,7 +420,7 @@ class ThumbnailGallery(Gtk.HBox):
                            GObject.TYPE_NONE,
                            (int,),), }
 
-    THUMBNAIL_SIZE_CONTRAINTS = 90, 80
+    THUMBNAIL_SIZE_CONSTRAINTS = 90, 80
     THUMBNAIL_MAX_COUNT = 3
 
     def __init__(self, gallery):
@@ -435,7 +437,7 @@ class ThumbnailGallery(Gtk.HBox):
         self.cancel.reset()
 
         for sig in self._handlers:
-            GObject.source_remove(sig)
+            GLib.source_remove(sig)
 
         for child in self:
             child.destroy()
