@@ -33,7 +33,6 @@ from softwarecenter.db.categories import CategoriesParser
 from softwarecenter.db.database import StoreDatabase
 from softwarecenter.db.pkginfo import get_pkg_info
 from softwarecenter.paths import XAPIAN_BASE_PATH
-import softwarecenter.paths
 
 
 class CategoriesModel(QAbstractListModel):
@@ -55,8 +54,7 @@ class CategoriesModel(QAbstractListModel):
         db.open()
         # /FIXME
         self.catparser = CategoriesParser(db)
-        self._categories = self.catparser.parse_applications_menu(
-            softwarecenter.paths.APP_INSTALL_PATH)
+        self._categories = self.catparser.parse_applications_menu()
 
     # QAbstractListModel code
     def rowCount(self, parent=QModelIndex()):
