@@ -17,7 +17,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from gi.repository import GObject
+from gi.repository import GLib
 from datetime import datetime
 
 from PyQt4.QtCore import QAbstractListModel, QModelIndex, pyqtSignal, pyqtSlot
@@ -91,7 +91,7 @@ class ReviewsListModel(QAbstractListModel):
             self.clear()
 
         # load in the eventloop to ensure that animations are not delayed
-        GObject.timeout_add(
+        GLib.timeout_add(
             10, self.reviews.get_reviews, app, page)
 
     # refresh review-stats (for qml)
