@@ -487,7 +487,6 @@ def get_file_path_from_iconname(icons, iconname=None,
         icon_info = icons.lookup_icon(Icons.MISSING_APP, iconsize, 0)
     if icon_info is not None:
         icon_file_path = icon_info.get_filename()
-        icon_info.free()
         return icon_file_path
 
 
@@ -512,20 +511,32 @@ def convert_desktop_file_to_installed_location(app_install_data_file_path,
     # lastly, just try checking directly for the desktop file based on the
     # pkgname itself for the case of for-purchase items, etc.
     if pkgname:
-        installed_desktop_file_path = "/usr/share/applications/%s.desktop" %\
-            pkgname
-        if os.path.exists(installed_desktop_file_path):
-            return installed_desktop_file_path
+        datadirs = GLib.get_system_data_dirs()
+        for dir in datadirs:
+            path = "%s/applications/%s.desktop" % (dir, pkgname)
+            if os.path.exists(path):
+                return path
+
         # files in the extras archive have their desktop filenames prepended
         # by "extras-", so we check for that also (LP: #1012877)
-        extras_desktop_file_path = \
-            "/usr/share/applications/extras-%s.desktop" % pkgname
-        if os.path.exists(extras_desktop_file_path):
-            return extras_desktop_file_path
+        for dir in datadirs:
+            path = "%s/applications/extras-%s.desktop" % (dir, pkgname)
+            if os.path.exists(path):
+                return path
     LOG.warn("Could not determine the installed desktop file path for "
              "app-install desktop file: '%s'" % app_install_data_file_path)
     return ""
 
+def get_desktop_id(desktop_file):
+    """ Gets a desktop-id from a .desktop file path"""
+    datadirs = [(i if i[-1] == '/' else i+'/') + 'applications/' for i in \
+                GLib.get_system_data_dirs() + [GLib.get_user_data_dir()]]
+
+    for dir in datadirs:
+        if desktop_file.startswith(dir):
+            return desktop_file[len(dir):].replace('/', '-')
+
+    return desktop_file
 
 def clear_token_from_ubuntu_sso_sync(appname):
     """ send a dbus signal to the com.ubuntu.sso service to clear
