@@ -1,7 +1,7 @@
 import unittest
 
 from gi.repository import (
-    GObject,
+    GLib,
     Gtk,
     )
 
@@ -25,19 +25,19 @@ class TestRecommendationsWidgets(unittest.TestCase):
         child = win.get_children()[0]
         child.connect("size-allocate", self._on_size_allocate)
         self.addCleanup(win.destroy)
-        GObject.timeout_add(TIMEOUT, Gtk.main_quit)
+        GLib.timeout_add(TIMEOUT, Gtk.main_quit)
         Gtk.main()
 
     def test_recommendations_category(self):
         win = get_test_window_recommendations(panel_type="category")
         self.addCleanup(win.destroy)
-        GObject.timeout_add(TIMEOUT, Gtk.main_quit)
+        GLib.timeout_add(TIMEOUT, Gtk.main_quit)
         Gtk.main()
 
     def test_recommendations_details(self):
         win = get_test_window_recommendations(panel_type="details")
         self.addCleanup(win.destroy)
-        GObject.timeout_add(TIMEOUT, Gtk.main_quit)
+        GLib.timeout_add(TIMEOUT, Gtk.main_quit)
         Gtk.main()
 
 
