@@ -8,7 +8,7 @@ import urllib
 import xapian
 
 from gi.repository import Gdk, Gtk, GLib
-from mock import Mock
+from mock import Mock, patch
 
 import softwarecenter.distro
 import softwarecenter.log
@@ -254,6 +254,7 @@ def get_test_window_availablepane():
     cache = get_test_pkg_info()
     icons = get_test_gtk3_icon_cache()
     backend = get_test_install_backend()
+    distro = softwarecenter.distro.get_distro()
 
     manager = appmanager.get_appmanager()
     if manager is None:
@@ -265,7 +266,12 @@ def get_test_window_availablepane():
     navhistory_forward_action = Gtk.Action("navhistory_forward_action",
         "Forward", "Forward", None)
 
-    w = availablepane.AvailablePane(cache, db, 'Ubuntu', icons,
+    zl = "softwarecenter.backend.zeitgeist_logger.ZeitgeistLogger";
+    patch(zl + ".log_install_event").start().return_value = False
+    patch(zl + ".log_uninstall_event").start().return_value = False
+    patch("softwarecenter.utils.is_unity_running").start().return_value = False
+
+    w = availablepane.AvailablePane(cache, db, distro, icons,
         navhistory_back_action, navhistory_forward_action)
     w.init_view()
     w.show()
