@@ -1,5 +1,4 @@
 import apt
-import platform
 import os
 import re
 import tempfile
@@ -102,6 +101,17 @@ class TestDatabase(unittest.TestCase):
         for it in db.postlist("AAUbuntu Software Zentrum"):
             i+=1
 
+    def test_update_includes_scope_files(self):
+        datadir = os.path.join(DATA_DIR, "desktop")
+        db = get_test_db_from_app_install_data(datadir)
+        for it in db.postlist("APMunity_lens_music"):
+            doc = db.get_document(it.docid)
+            self.assertEqual(
+                doc.get_value(XapianValues.APPNAME), "Music (Banshee)")
+            break
+        else:
+            self.fail("Did not find scope file in Xapian database")
+
     def test_regression_index_terms(self):
         """ this tests for a regression that we had in the term indexer
             that would index hundrets of size 1 terms due to a bug
@@ -135,7 +145,7 @@ class TestDatabase(unittest.TestCase):
                 self.assertIsInstance(value.num, long)
                 self.assertIsInstance(value.value, basestring)
 
-    @unittest.skipIf(platform.dist()[2] == "precise", "needs quantal or later")
+    @unittest.skip("Unreliable: incorrect indices get downloaded")
     def test_update_from_var_lib_apt_lists(self):
         # ensure we index with german locales to test i18n
         os.environ["LANGUAGE"] = "de"
@@ -230,7 +240,7 @@ class TestDatabase(unittest.TestCase):
         self.assertTrue(res)
         db = StoreDatabase(TEST_DB, self.cache)
         db.open(use_axi=False, use_agent=False)
-        self.assertEqual(len(db), 5)
+        self.assertEqual(len(db), 6)
         # test details
         app = Application("Ubuntu Software Center Test", "software-center")
         details = app.get_details(db)
@@ -940,6 +950,4 @@ class DBSearchTestCase(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    #import logging
-    #logging.basicConfig(level=logging.DEBUG)
     unittest.main()
