@@ -3,7 +3,7 @@ import platform
 import unittest
 import xapian
 
-from gi.repository import GObject
+from gi.repository import GLib
 
 from mock import patch
 from piston_mini_client import PistonResponseObject
@@ -96,7 +96,8 @@ AVAILABLE_APPS_JSON = """
         "categories": "AudioVideo",
         "description": "Play DVD-Videos\\r\\n\\r\\nFluendo DVD Player is a software application specially designed to\\r\\nreproduce DVD on Linux/Unix platforms, which provides end users with\\r\\nhigh quality standards.\\r\\n\\r\\nThe following features are provided:\\r\\n* Full DVD Playback\\r\\n* DVD Menu support\\r\\n* Fullscreen support\\r\\n* Dolby Digital pass-through\\r\\n* Dolby Digital 5.1 output and stereo downmixing support\\r\\n* Resume from last position support\\r\\n* Subtitle support\\r\\n* Audio selection support\\r\\n* Multiple Angles support\\r\\n* Support for encrypted discs\\r\\n* Multiregion, works in all regions\\r\\n* Multiple video deinterlacing algorithms",
         "website": null,
-        "version": "1.2.1"
+        "version": "1.2.1",
+        "binary_filesize": 12345
     },
     {
     "website": "",
@@ -163,6 +164,12 @@ class SCAApplicationParserTestCase(unittest.TestCase):
         self.assertEqual('Fluendo DVD Player',
                          parser.get_value(AppInfoFields.NAME))
 
+    def test_binary_filesize(self):
+        parser = self._make_application_parser()
+
+        self.assertEqual(12345,
+                         parser.get_value(AppInfoFields.DOWNLOAD_SIZE))
+
     def test_keys_not_provided_by_api(self):
         parser = self._make_application_parser()
 
@@ -366,9 +373,9 @@ class TestAvailableForMeMerging(unittest.TestCase):
 
     def _make_fake_scagent(self, available_data, available_for_me_data):
         sca = ObjectWithSignals()
-        sca.query_available = lambda **kwargs: GObject.timeout_add(
+        sca.query_available = lambda **kwargs: GLib.timeout_add(
                 100, lambda: sca.emit('available', sca, available_data))
-        sca.query_available_for_me = lambda **kwargs: GObject.timeout_add(
+        sca.query_available_for_me = lambda **kwargs: GLib.timeout_add(
             100, lambda: sca.emit('available-for-me', 
                                   sca, available_for_me_data))
         return sca
