@@ -18,6 +18,7 @@ from tests.utils import (
     get_test_gtk3_icon_cache,
     setup_test_env,
     UTILS_DIR,
+    DATA_DIR,
 )
 setup_test_env()
 
@@ -35,7 +36,9 @@ from softwarecenter.utils import (
     get_title_from_html,
     get_uuid,
     get_recommender_uuid,
+    get_desktop_id,
     is_no_display_desktop_file,
+    convert_desktop_file_to_installed_location,
     make_string_from_list,
     release_filename_in_lists_from_deb_line,
     safe_makedirs,
@@ -121,6 +124,16 @@ class TestSCUtils(unittest.TestCase):
         d = "/usr/share/app-install/desktop/software-center:ubuntu-software-center.desktop"
         self.assertFalse(is_no_display_desktop_file(d))
 
+    def test_get_desktop_id(self):
+        self.assertEqual(get_desktop_id("/usr/share/applications/ubuntu-software-center.desktop"),
+                                        "ubuntu-software-center.desktop")
+        self.assertEqual(get_desktop_id("/usr/share/applications/kde4-anyapp.desktop"),
+                                        "kde4-anyapp.desktop")
+        self.assertEqual(get_desktop_id("/usr/share/applications/kde4/anyapp.desktop"),
+                                        "kde4-anyapp.desktop")
+        self.assertEqual(get_desktop_id("/my/own/path/application.desktop"),
+                                        "/my/own/path/application.desktop")
+
     def test_split_icon_ext(self):
         for unchanged in ["foo.bar.baz", "foo.bar", "foo",
                           "foo.pngx", "foo.png.xxx"]:
@@ -317,5 +330,44 @@ class TestExpungeCache(unittest.TestCase):
         save_person_to_config("meep")
         self.assertEqual(get_person_from_config(), "meep")
 
+
+class DesktopFilepathConversionTestCase(unittest.TestCase):
+    def test_normal(self):
+        # test 'normal' case
+        app_install_desktop_path = os.path.join(DATA_DIR, "app-install",
+            "desktop", "deja-dup:deja-dup.desktop")
+        installed_desktop_path = convert_desktop_file_to_installed_location(
+                app_install_desktop_path, "deja-dup")
+        self.assertEqual(installed_desktop_path, os.path.join(DATA_DIR, 
+                         "applications", "deja-dup.desktop"))
+
+    def test_encoded_subdir(self):
+        # test encoded subdirectory case, e.g. e.g. kde4_soundkonverter.desktop
+        app_install_desktop_path = os.path.join(DATA_DIR, "app-install",
+            "desktop", "soundkonverter:kde4__soundkonverter.desktop")
+        installed_desktop_path = convert_desktop_file_to_installed_location(
+                app_install_desktop_path, "soundkonverter")
+        self.assertEqual(installed_desktop_path, os.path.join(DATA_DIR,
+                         "applications", "kde4", "soundkonverter.desktop"))
+
+    def test_purchase_via_software_center_agent(self):
+        # test the for-purchase case (uses "software-center-agent" as its
+        # appdetails.desktop_file value)
+        # FIXME: this will only work if update-manager is installed
+        app_install_desktop_path = "software-center-agent"
+        installed_desktop_path = convert_desktop_file_to_installed_location(
+                app_install_desktop_path, "update-manager")
+        self.assertEqual(installed_desktop_path,
+                         "/usr/share/applications/update-manager.desktop")
+
+    def test_no_value(self):
+        # test case where we don't have a value for app_install_desktop_path
+        # (e.g. for a local .deb install, see bug LP: #768158)
+        installed_desktop_path = convert_desktop_file_to_installed_location(
+                None, "update-manager")
+        # FIXME: this will only work if update-manager is installed
+        self.assertEqual(installed_desktop_path,
+                         "/usr/share/applications/update-manager.desktop")
+
 if __name__ == "__main__":
     unittest.main()
