@@ -6,8 +6,9 @@ import sys
 import xapian
 
 sys.path.insert(0, "../")
-from softwarecenter.enums import *
-from softwarecenter.utils import *
+from softwarecenter.enums import XAPIAN_VALUE_PKGNAME, XAPIAN_VALUE_APPNAME, XAPIAN_VALUE_SUMMARY
+from softwarecenter.paths import XAPIAN_BASE_PATH
+
 
 if __name__ == "__main__":
 
@@ -22,7 +23,7 @@ if __name__ == "__main__":
         pkgname = doc.get_value(XAPIAN_VALUE_PKGNAME)
         appname = doc.get_value(XAPIAN_VALUE_APPNAME)
         summary = doc.get_value(XAPIAN_VALUE_SUMMARY)
-        if cache.has_key(pkgname) and cache[pkgname].isInstalled:
+        if pkgname in cache and cache[pkgname].is_installed:
             installed.append("%s: %s [%s]" % (appname, summary, pkgname))
 
     print "\n".join(sorted(installed, 
