@@ -25,7 +25,6 @@ import json
 import pickle
 import sys
 
-from gi.repository import GObject
 
 # useful for debugging
 if "SOFTWARE_CENTER_DEBUG_HTTP" in os.environ:
@@ -45,13 +44,8 @@ except ImportError:
 
 import softwarecenter.paths
 from softwarecenter.paths import SOFTWARE_CENTER_CACHE_DIR
-from softwarecenter.backend.login_sso import get_sso_backend
 
-from softwarecenter.enums import (SOFTWARE_CENTER_NAME_KEYRING,
-                                  SOFTWARE_CENTER_SSO_DESCRIPTION,
-                                  )
-                                  
-from softwarecenter.utils import clear_token_from_ubuntu_sso_sync
+from softwarecenter.backend.ubuntusso import UbuntuSSO
 
 # the piston import
 from softwarecenter.backend.piston.ubuntusso_pristine import UbuntuSsoAPI
@@ -60,90 +54,23 @@ from softwarecenter.backend.piston.scaclient import SoftwareCenterAgentAPI
 from softwarecenter.backend.piston.sreclient_pristine import (
     SoftwareCenterRecommenderAPI)
 
-# patch default_service_root to the one we use
-from softwarecenter.enums import UBUNTU_SSO_SERVICE
-# *Don't* append /api/1.0, as it's already included in UBUNTU_SSO_SERVICE
-UbuntuSsoAPI.default_service_root = UBUNTU_SSO_SERVICE
 
 from softwarecenter.enums import RECOMMENDER_HOST
 SoftwareCenterRecommenderAPI.default_service_root =  \
     RECOMMENDER_HOST + "/api/1.0"
 
 
+# patch default_service_root to the one we use
+from softwarecenter.enums import UBUNTU_SSO_SERVICE
+# *Don't* append /api/1.0, as it's already included in UBUNTU_SSO_SERVICE
+UbuntuSsoAPI.default_service_root = UBUNTU_SSO_SERVICE
+
+
 RatingsAndReviewsAPI # pyflakes
 UbuntuSsoAPI # pyflakes
 SoftwareCenterAgentAPI # pyflakes
 SoftwareCenterRecommenderAPI # pyflakes
 
-from gettext import gettext as _
-
-
-# helper that is only used to verify that the token is ok
-# and trigger cleanup if not
-class SSOLoginHelper(object):
-
-    def __init__(self, xid=0):
-        self.oauth = None
-        self.xid = xid
-        self.loop = GObject.MainLoop(GObject.main_context_default())
-    
-    def _login_successful(self, sso_backend, oauth_result):
-        LOG.debug("_login_successful")
-        self.oauth = oauth_result
-        # FIXME: actually verify the token against ubuntu SSO
-        self.loop.quit()
-
-    def verify_token_sync(self, token):
-        """ Verify that the token is valid
-        
-            Note that this may raise httplib2 exceptions if the server
-            is not reachable
-        """
-        LOG.debug("verify_token")
-        auth = piston_mini_client.auth.OAuthAuthorizer(
-            token["token"], token["token_secret"],
-            token["consumer_key"], token["consumer_secret"])
-        api = UbuntuSsoAPI(auth=auth)
-        try:
-            res = api.whoami()
-        except piston_mini_client.failhandlers.APIError as e:
-            LOG.exception("api.whoami failed with APIError: '%s'" % e)
-            return False
-        return len(res) > 0
-
-    def clear_token(self):
-        clear_token_from_ubuntu_sso_sync(SOFTWARE_CENTER_NAME_KEYRING)
-
-    def get_oauth_token_sync(self):
-        self.oauth = None
-        sso = get_sso_backend(
-            self.xid, 
-            SOFTWARE_CENTER_NAME_KEYRING,
-            _(SOFTWARE_CENTER_SSO_DESCRIPTION))
-        sso.connect("login-successful", self._login_successful)
-        sso.connect("login-failed", lambda s: self.loop.quit())
-        sso.connect("login-canceled", lambda s: self.loop.quit())
-        sso.login_or_register()
-        self.loop.run()
-        return self.oauth
-
-    def get_oauth_token_and_verify_sync(self):
-        token = self.get_oauth_token_sync()
-        # check if the token is valid and reset it if it is not
-        if token:
-            # verify token will return false if there is a API error, 
-            # but there maybe httplib2 errors if there is no network,
-            # so ignore them
-            try:
-                if not self.verify_token_sync(token):
-                    self.clear_token()
-                    # re-trigger login once
-                    token = self.get_oauth_token_sync()
-            except Exception as e:
-                LOG.warn(
-                    "token could not be verified (network problem?): %s" % e)
-        return token
-
 
 LOG = logging.getLogger(__name__)
 
@@ -159,8 +86,13 @@ if __name__ == "__main__":
                         help="setup alternative datadir")
     parser.add_argument("--ignore-cache", action="store_true", default=False,
                         help="force ignore cache")
+    parser.add_argument("--disable-offline-mode", action="store_true", 
+                        default=False,
+                        help="force disable offline mode")
     parser.add_argument("--needs-auth", default=False, action="store_true",
                         help="need oauth credentials")
+    parser.add_argument("--no-relogin", default=False, action="store_true",
+                        help="do not attempt relogin if token is invalid")
     parser.add_argument("--output", default="pickle",
                         help="output result as [pickle|json|text]")
     parser.add_argument("--parent-xid", default=0,
@@ -188,8 +120,9 @@ if __name__ == "__main__":
     softwarecenter.paths.datadir = args.datadir
 
     if args.needs_auth:
-        helper = SSOLoginHelper(args.parent_xid)
-        token = helper.get_oauth_token_and_verify_sync()
+        helper = UbuntuSSO(args.parent_xid)
+        token = helper.get_oauth_token_and_verify_sync(
+            no_relogin=args.no_relogin)
         # if we don't have a token, error here
         if not token:
             # it may happen that the parent is closed already so the pipe
@@ -213,8 +146,14 @@ if __name__ == "__main__":
     try:
         piston_reply = f(**kwargs)
     except httplib2.ServerNotFoundError as e:
-        LOG.warn(e)
-        sys.exit(1)
+        if not args.disable_offline_mode:
+            # switch to offline mode and try again from the cache
+            try:
+                api._offline_mode = True
+                piston_reply = f(**kwargs)
+            except Exception as e:
+                LOG.warn(e)
+                sys.exit(1)
     except APIError as e:
         LOG.warn(e)
         sys.exit(1)
@@ -222,10 +161,12 @@ if __name__ == "__main__":
         LOG.exception("urclient_apps")
         sys.exit(1)
 
-    # print to stdout where its consumed by the parent
+    # no data is a error, the server does always return something,
+    # this can happen if e.g. we try cached data but have nothing
+    # in the cache
     if piston_reply is None:
         LOG.warn("no data")
-        sys.exit(0)
+        sys.exit(1)
 
     if args.debug:
         for itm in piston_reply:
@@ -234,6 +175,8 @@ if __name__ == "__main__":
                 s += "%s: '%s'\n" % (var, getattr(itm, var))
             LOG.debug(s)
 
+    # print to stdout where its consumed by the parent
+
     # check what format to use
     if args.output == "pickle":
         res = pickle.dumps(piston_reply)
